Class: Google::Apis::AppengineV1::Deployment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

Code and application artifacts used to deploy a version to App Engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Deployment

Returns a new instance of Deployment.



819
820
821
# File 'lib/google/apis/appengine_v1/classes.rb', line 819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_build_optionsGoogle::Apis::AppengineV1::CloudBuildOptions

Options for the build operations performed as a part of the version deployment. Only applicable for App Engine flexible environment when creating a version using source code directly. Corresponds to the JSON property cloudBuildOptions



798
799
800
# File 'lib/google/apis/appengine_v1/classes.rb', line 798

def cloud_build_options
  @cloud_build_options
end

#containerGoogle::Apis::AppengineV1::ContainerInfo

Docker image that is used to create a container and start a VM instance for the version that you deploy. Only applicable for instances running in the App Engine flexible environment. Corresponds to the JSON property container



805
806
807
# File 'lib/google/apis/appengine_v1/classes.rb', line 805

def container
  @container
end

#filesHash<String,Google::Apis::AppengineV1::FileInfo>

Manifest of the files stored in Google Cloud Storage that are included as part of this version. All files must be readable using the credentials supplied with this call. Corresponds to the JSON property files

Returns:



812
813
814
# File 'lib/google/apis/appengine_v1/classes.rb', line 812

def files
  @files
end

#zipGoogle::Apis::AppengineV1::ZipInfo

The zip file information for a zip deployment. Corresponds to the JSON property zip



817
818
819
# File 'lib/google/apis/appengine_v1/classes.rb', line 817

def zip
  @zip
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



824
825
826
827
828
829
# File 'lib/google/apis/appengine_v1/classes.rb', line 824

def update!(**args)
  @cloud_build_options = args[:cloud_build_options] if args.key?(:cloud_build_options)
  @container = args[:container] if args.key?(:container)
  @files = args[:files] if args.key?(:files)
  @zip = args[:zip] if args.key?(:zip)
end