Class: Google::Apis::AppengineV1::DomainMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

A domain serving an App Engine application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DomainMapping

Returns a new instance of DomainMapping.



897
898
899
# File 'lib/google/apis/appengine_v1/classes.rb', line 897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Relative name of the domain serving the application. Example: example.com. Corresponds to the JSON property id

Returns:

  • (String)


877
878
879
# File 'lib/google/apis/appengine_v1/classes.rb', line 877

def id
  @id
end

#nameString

Output only. Full path to the DomainMapping resource in the API. Example: apps/ myapp/domainMapping/example.com.@OutputOnly Corresponds to the JSON property name

Returns:

  • (String)


883
884
885
# File 'lib/google/apis/appengine_v1/classes.rb', line 883

def name
  @name
end

#resource_recordsArray<Google::Apis::AppengineV1::ResourceRecord>

Output only. The resource records required to configure this domain mapping. These records must be added to the domain's DNS configuration in order to serve the application via this domain mapping.@OutputOnly Corresponds to the JSON property resourceRecords



890
891
892
# File 'lib/google/apis/appengine_v1/classes.rb', line 890

def resource_records
  @resource_records
end

#ssl_settingsGoogle::Apis::AppengineV1::SslSettings

SSL configuration for a DomainMapping resource. Corresponds to the JSON property sslSettings



895
896
897
# File 'lib/google/apis/appengine_v1/classes.rb', line 895

def ssl_settings
  @ssl_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



902
903
904
905
906
907
# File 'lib/google/apis/appengine_v1/classes.rb', line 902

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @resource_records = args[:resource_records] if args.key?(:resource_records)
  @ssl_settings = args[:ssl_settings] if args.key?(:ssl_settings)
end