Class: Google::Apis::AppengineV1::EndpointsApiService

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

Google Cloud Endpoints (https://cloud.google.com/endpoints) configuration. The Endpoints API Service provides tooling for serving Open API and gRPC endpoints via an NGINX proxy. Only valid for App Engine Flexible environment deployments. The fields here refer to the name and configuration ID of a "service" resource in the Service Management API (https://cloud.google.com/service-management/ overview).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndpointsApiService

Returns a new instance of EndpointsApiService.



966
967
968
# File 'lib/google/apis/appengine_v1/classes.rb', line 966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_idString

Endpoints service configuration ID as specified by the Service Management API. For example "2016-09-19r1".By default, the rollout strategy for Endpoints is RolloutStrategy.FIXED. This means that Endpoints starts up with a particular configuration ID. When a new configuration is rolled out, Endpoints must be given the new configuration ID. The config_id field is used to give the configuration ID and is required in this case.Endpoints also has a rollout strategy called RolloutStrategy.MANAGED. When using this, Endpoints fetches the latest configuration and does not need the configuration ID. In this case, config_id must be omitted. Corresponds to the JSON property configId

Returns:

  • (String)


946
947
948
# File 'lib/google/apis/appengine_v1/classes.rb', line 946

def config_id
  @config_id
end

#disable_trace_samplingBoolean Also known as: disable_trace_sampling?

Enable or disable trace sampling. By default, this is set to false for enabled. Corresponds to the JSON property disableTraceSampling

Returns:

  • (Boolean)


951
952
953
# File 'lib/google/apis/appengine_v1/classes.rb', line 951

def disable_trace_sampling
  @disable_trace_sampling
end

#nameString

Endpoints service name which is the name of the "service" resource in the Service Management API. For example "myapi.endpoints.myproject.cloud.goog" Corresponds to the JSON property name

Returns:

  • (String)


958
959
960
# File 'lib/google/apis/appengine_v1/classes.rb', line 958

def name
  @name
end

#rollout_strategyString

Endpoints rollout strategy. If FIXED, config_id must be specified. If MANAGED, config_id must be omitted. Corresponds to the JSON property rolloutStrategy

Returns:

  • (String)


964
965
966
# File 'lib/google/apis/appengine_v1/classes.rb', line 964

def rollout_strategy
  @rollout_strategy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



971
972
973
974
975
976
# File 'lib/google/apis/appengine_v1/classes.rb', line 971

def update!(**args)
  @config_id = args[:config_id] if args.key?(:config_id)
  @disable_trace_sampling = args[:disable_trace_sampling] if args.key?(:disable_trace_sampling)
  @name = args[:name] if args.key?(:name)
  @rollout_strategy = args[:rollout_strategy] if args.key?(:rollout_strategy)
end