Class: Google::Apis::AppengineV1::ExportAppImageRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

Request message for Versions.ExportAppImage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportAppImageRequest

Returns a new instance of ExportAppImageRequest.



1048
1049
1050
# File 'lib/google/apis/appengine_v1/classes.rb', line 1048

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_repositoryString

Optional. The full resource name of the AR repository to export to. Format: projects/project/locations/location/repositories/repository If not specified, defaults to projects/project/locations/location/repositories/ gae-standard in the same region as the app. The default repository will be created if it does not exist. Corresponds to the JSON property destinationRepository

Returns:

  • (String)


1040
1041
1042
# File 'lib/google/apis/appengine_v1/classes.rb', line 1040

def destination_repository
  @destination_repository
end

#service_accountString

Optional. Optional: A service account to use for authenticating to Artifact Registry. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


1046
1047
1048
# File 'lib/google/apis/appengine_v1/classes.rb', line 1046

def 
  @service_account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1053
1054
1055
1056
# File 'lib/google/apis/appengine_v1/classes.rb', line 1053

def update!(**args)
  @destination_repository = args[:destination_repository] if args.key?(:destination_repository)
  @service_account = args[:service_account] if args.key?(:service_account)
end