Class: Google::Apis::AppengineV1::FileInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

Single source file that is part of the version to be deployed. Each source file that is deployed must be specified separately.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileInfo

Returns a new instance of FileInfo.



1113
1114
1115
# File 'lib/google/apis/appengine_v1/classes.rb', line 1113

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mime_typeString

The MIME type of the file.Defaults to the value from Google Cloud Storage. Corresponds to the JSON property mimeType

Returns:

  • (String)


1100
1101
1102
# File 'lib/google/apis/appengine_v1/classes.rb', line 1100

def mime_type
  @mime_type
end

#sha1_sumString

The SHA1 hash of the file, in hex. Corresponds to the JSON property sha1Sum

Returns:

  • (String)


1105
1106
1107
# File 'lib/google/apis/appengine_v1/classes.rb', line 1105

def sha1_sum
  @sha1_sum
end

#source_urlString

URL source to use to fetch this file. Must be a URL to a resource in Google Cloud Storage in the form 'http(s)://storage.googleapis.com//'. Corresponds to the JSON property sourceUrl

Returns:

  • (String)


1111
1112
1113
# File 'lib/google/apis/appengine_v1/classes.rb', line 1111

def source_url
  @source_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1118
1119
1120
1121
1122
# File 'lib/google/apis/appengine_v1/classes.rb', line 1118

def update!(**args)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @sha1_sum = args[:sha1_sum] if args.key?(:sha1_sum)
  @source_url = args[:source_url] if args.key?(:source_url)
end