Class: Google::Apis::AppengineV1::FlexibleRuntimeSettings
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::FlexibleRuntimeSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
Runtime settings for the App Engine flexible environment.
Instance Attribute Summary collapse
-
#operating_system ⇒ String
The operating system of the application runtime.
-
#runtime_version ⇒ String
The runtime version of an App Engine flexible application.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlexibleRuntimeSettings
constructor
A new instance of FlexibleRuntimeSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlexibleRuntimeSettings
Returns a new instance of FlexibleRuntimeSettings.
1188 1189 1190 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1188 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operating_system ⇒ String
The operating system of the application runtime.
Corresponds to the JSON property operatingSystem
1181 1182 1183 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1181 def @operating_system end |
#runtime_version ⇒ String
The runtime version of an App Engine flexible application.
Corresponds to the JSON property runtimeVersion
1186 1187 1188 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1186 def runtime_version @runtime_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1193 1194 1195 1196 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1193 def update!(**args) @operating_system = args[:operating_system] if args.key?(:operating_system) @runtime_version = args[:runtime_version] if args.key?(:runtime_version) end |