Class: Google::Apis::AppengineV1::HealthCheck

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

Health checking configuration for VM instances. Unhealthy instances are killed and replaced with new instances. Only applicable for instances in App Engine flexible environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheck

Returns a new instance of HealthCheck.



1300
1301
1302
# File 'lib/google/apis/appengine_v1/classes.rb', line 1300

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_intervalString

Interval between health checks. Corresponds to the JSON property checkInterval

Returns:

  • (String)


1264
1265
1266
# File 'lib/google/apis/appengine_v1/classes.rb', line 1264

def check_interval
  @check_interval
end

#disable_health_checkBoolean Also known as: disable_health_check?

Whether to explicitly disable health checks for this instance. Corresponds to the JSON property disableHealthCheck

Returns:

  • (Boolean)


1269
1270
1271
# File 'lib/google/apis/appengine_v1/classes.rb', line 1269

def disable_health_check
  @disable_health_check
end

#healthy_thresholdFixnum

Number of consecutive successful health checks required before receiving traffic. Corresponds to the JSON property healthyThreshold

Returns:

  • (Fixnum)


1276
1277
1278
# File 'lib/google/apis/appengine_v1/classes.rb', line 1276

def healthy_threshold
  @healthy_threshold
end

#hostString

Host header to send when performing an HTTP health check. Example: "myapp. appspot.com" Corresponds to the JSON property host

Returns:

  • (String)


1282
1283
1284
# File 'lib/google/apis/appengine_v1/classes.rb', line 1282

def host
  @host
end

#restart_thresholdFixnum

Number of consecutive failed health checks required before an instance is restarted. Corresponds to the JSON property restartThreshold

Returns:

  • (Fixnum)


1288
1289
1290
# File 'lib/google/apis/appengine_v1/classes.rb', line 1288

def restart_threshold
  @restart_threshold
end

#timeoutString

Time before the health check is considered failed. Corresponds to the JSON property timeout

Returns:

  • (String)


1293
1294
1295
# File 'lib/google/apis/appengine_v1/classes.rb', line 1293

def timeout
  @timeout
end

#unhealthy_thresholdFixnum

Number of consecutive failed health checks required before removing traffic. Corresponds to the JSON property unhealthyThreshold

Returns:

  • (Fixnum)


1298
1299
1300
# File 'lib/google/apis/appengine_v1/classes.rb', line 1298

def unhealthy_threshold
  @unhealthy_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1305
1306
1307
1308
1309
1310
1311
1312
1313
# File 'lib/google/apis/appengine_v1/classes.rb', line 1305

def update!(**args)
  @check_interval = args[:check_interval] if args.key?(:check_interval)
  @disable_health_check = args[:disable_health_check] if args.key?(:disable_health_check)
  @healthy_threshold = args[:healthy_threshold] if args.key?(:healthy_threshold)
  @host = args[:host] if args.key?(:host)
  @restart_threshold = args[:restart_threshold] if args.key?(:restart_threshold)
  @timeout = args[:timeout] if args.key?(:timeout)
  @unhealthy_threshold = args[:unhealthy_threshold] if args.key?(:unhealthy_threshold)
end