Class: Google::Apis::AppengineV1::Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

An Instance resource is the computing unit that App Engine uses to automatically scale an application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



1458
1459
1460
# File 'lib/google/apis/appengine_v1/classes.rb', line 1458

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_engine_releaseString

Output only. App Engine release this instance is running on. Corresponds to the JSON property appEngineRelease

Returns:

  • (String)


1366
1367
1368
# File 'lib/google/apis/appengine_v1/classes.rb', line 1366

def app_engine_release
  @app_engine_release
end

#availabilityString

Output only. Availability of the instance. Corresponds to the JSON property availability

Returns:

  • (String)


1371
1372
1373
# File 'lib/google/apis/appengine_v1/classes.rb', line 1371

def availability
  @availability
end

#average_latencyFixnum

Output only. Average latency (ms) over the last minute. Corresponds to the JSON property averageLatency

Returns:

  • (Fixnum)


1376
1377
1378
# File 'lib/google/apis/appengine_v1/classes.rb', line 1376

def average_latency
  @average_latency
end

#errorsFixnum

Output only. Number of errors since this instance was started. Corresponds to the JSON property errors

Returns:

  • (Fixnum)


1381
1382
1383
# File 'lib/google/apis/appengine_v1/classes.rb', line 1381

def errors
  @errors
end

#idString

Output only. Relative name of the instance within the version. Example: instance-1. Corresponds to the JSON property id

Returns:

  • (String)


1387
1388
1389
# File 'lib/google/apis/appengine_v1/classes.rb', line 1387

def id
  @id
end

#memory_usageFixnum

Output only. Total memory in use (bytes). Corresponds to the JSON property memoryUsage

Returns:

  • (Fixnum)


1392
1393
1394
# File 'lib/google/apis/appengine_v1/classes.rb', line 1392

def memory_usage
  @memory_usage
end

#nameString

Output only. Full path to the Instance resource in the API. Example: apps/ myapp/services/default/versions/v1/instances/instance-1. Corresponds to the JSON property name

Returns:

  • (String)


1398
1399
1400
# File 'lib/google/apis/appengine_v1/classes.rb', line 1398

def name
  @name
end

#qpsFloat

Output only. Average queries per second (QPS) over the last minute. Corresponds to the JSON property qps

Returns:

  • (Float)


1403
1404
1405
# File 'lib/google/apis/appengine_v1/classes.rb', line 1403

def qps
  @qps
end

#requestsFixnum

Output only. Number of requests since this instance was started. Corresponds to the JSON property requests

Returns:

  • (Fixnum)


1408
1409
1410
# File 'lib/google/apis/appengine_v1/classes.rb', line 1408

def requests
  @requests
end

#start_timeString

Output only. Time that this instance was started.@OutputOnly Corresponds to the JSON property startTime

Returns:

  • (String)


1413
1414
1415
# File 'lib/google/apis/appengine_v1/classes.rb', line 1413

def start_time
  @start_time
end

#vm_debug_enabledBoolean Also known as: vm_debug_enabled?

Output only. Whether this instance is in debug mode. Only applicable for instances in App Engine flexible environment. Corresponds to the JSON property vmDebugEnabled

Returns:

  • (Boolean)


1419
1420
1421
# File 'lib/google/apis/appengine_v1/classes.rb', line 1419

def vm_debug_enabled
  @vm_debug_enabled
end

#vm_idString

Output only. Virtual machine ID of this instance. Only applicable for instances in App Engine flexible environment. Corresponds to the JSON property vmId

Returns:

  • (String)


1426
1427
1428
# File 'lib/google/apis/appengine_v1/classes.rb', line 1426

def vm_id
  @vm_id
end

#vm_ipString

Output only. The IP address of this instance. Only applicable for instances in App Engine flexible environment. Corresponds to the JSON property vmIp

Returns:

  • (String)


1432
1433
1434
# File 'lib/google/apis/appengine_v1/classes.rb', line 1432

def vm_ip
  @vm_ip
end

#vm_livenessString

Output only. The liveness health check of this instance. Only applicable for instances in App Engine flexible environment. Corresponds to the JSON property vmLiveness

Returns:

  • (String)


1438
1439
1440
# File 'lib/google/apis/appengine_v1/classes.rb', line 1438

def vm_liveness
  @vm_liveness
end

#vm_nameString

Output only. Name of the virtual machine where this instance lives. Only applicable for instances in App Engine flexible environment. Corresponds to the JSON property vmName

Returns:

  • (String)


1444
1445
1446
# File 'lib/google/apis/appengine_v1/classes.rb', line 1444

def vm_name
  @vm_name
end

#vm_statusString

Output only. Status of the virtual machine where this instance lives. Only applicable for instances in App Engine flexible environment. Corresponds to the JSON property vmStatus

Returns:

  • (String)


1450
1451
1452
# File 'lib/google/apis/appengine_v1/classes.rb', line 1450

def vm_status
  @vm_status
end

#vm_zone_nameString

Output only. Zone where the virtual machine is located. Only applicable for instances in App Engine flexible environment. Corresponds to the JSON property vmZoneName

Returns:

  • (String)


1456
1457
1458
# File 'lib/google/apis/appengine_v1/classes.rb', line 1456

def vm_zone_name
  @vm_zone_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
# File 'lib/google/apis/appengine_v1/classes.rb', line 1463

def update!(**args)
  @app_engine_release = args[:app_engine_release] if args.key?(:app_engine_release)
  @availability = args[:availability] if args.key?(:availability)
  @average_latency = args[:average_latency] if args.key?(:average_latency)
  @errors = args[:errors] if args.key?(:errors)
  @id = args[:id] if args.key?(:id)
  @memory_usage = args[:memory_usage] if args.key?(:memory_usage)
  @name = args[:name] if args.key?(:name)
  @qps = args[:qps] if args.key?(:qps)
  @requests = args[:requests] if args.key?(:requests)
  @start_time = args[:start_time] if args.key?(:start_time)
  @vm_debug_enabled = args[:vm_debug_enabled] if args.key?(:vm_debug_enabled)
  @vm_id = args[:vm_id] if args.key?(:vm_id)
  @vm_ip = args[:vm_ip] if args.key?(:vm_ip)
  @vm_liveness = args[:vm_liveness] if args.key?(:vm_liveness)
  @vm_name = args[:vm_name] if args.key?(:vm_name)
  @vm_status = args[:vm_status] if args.key?(:vm_status)
  @vm_zone_name = args[:vm_zone_name] if args.key?(:vm_zone_name)
end