Class: Google::Apis::AppengineV1::ListIngressRulesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::ListIngressRulesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
Response message for Firewall.ListIngressRules.
Instance Attribute Summary collapse
-
#ingress_rules ⇒ Array<Google::Apis::AppengineV1::FirewallRule>
The ingress FirewallRules for this application.
-
#next_page_token ⇒ String
Continuation token for fetching the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListIngressRulesResponse
constructor
A new instance of ListIngressRulesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListIngressRulesResponse
Returns a new instance of ListIngressRulesResponse.
1605 1606 1607 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ingress_rules ⇒ Array<Google::Apis::AppengineV1::FirewallRule>
The ingress FirewallRules for this application.
Corresponds to the JSON property ingressRules
1598 1599 1600 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1598 def ingress_rules @ingress_rules end |
#next_page_token ⇒ String
Continuation token for fetching the next page of results.
Corresponds to the JSON property nextPageToken
1603 1604 1605 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1603 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1610 1611 1612 1613 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1610 def update!(**args) @ingress_rules = args[:ingress_rules] if args.key?(:ingress_rules) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |