Class: Google::Apis::AppengineV1::LivenessCheck

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

Health checking configuration for VM instances. Unhealthy instances are killed and replaced with new instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LivenessCheck

Returns a new instance of LivenessCheck.



1810
1811
1812
# File 'lib/google/apis/appengine_v1/classes.rb', line 1810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_intervalString

Interval between health checks. Corresponds to the JSON property checkInterval

Returns:

  • (String)


1775
1776
1777
# File 'lib/google/apis/appengine_v1/classes.rb', line 1775

def check_interval
  @check_interval
end

#failure_thresholdFixnum

Number of consecutive failed checks required before considering the VM unhealthy. Corresponds to the JSON property failureThreshold

Returns:

  • (Fixnum)


1781
1782
1783
# File 'lib/google/apis/appengine_v1/classes.rb', line 1781

def failure_threshold
  @failure_threshold
end

#hostString

Host header to send when performing a HTTP Liveness check. Example: "myapp. appspot.com" Corresponds to the JSON property host

Returns:

  • (String)


1787
1788
1789
# File 'lib/google/apis/appengine_v1/classes.rb', line 1787

def host
  @host
end

#initial_delayString

The initial delay before starting to execute the checks. Corresponds to the JSON property initialDelay

Returns:

  • (String)


1792
1793
1794
# File 'lib/google/apis/appengine_v1/classes.rb', line 1792

def initial_delay
  @initial_delay
end

#pathString

The request path. Corresponds to the JSON property path

Returns:

  • (String)


1797
1798
1799
# File 'lib/google/apis/appengine_v1/classes.rb', line 1797

def path
  @path
end

#success_thresholdFixnum

Number of consecutive successful checks required before considering the VM healthy. Corresponds to the JSON property successThreshold

Returns:

  • (Fixnum)


1803
1804
1805
# File 'lib/google/apis/appengine_v1/classes.rb', line 1803

def success_threshold
  @success_threshold
end

#timeoutString

Time before the check is considered failed. Corresponds to the JSON property timeout

Returns:

  • (String)


1808
1809
1810
# File 'lib/google/apis/appengine_v1/classes.rb', line 1808

def timeout
  @timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1815
1816
1817
1818
1819
1820
1821
1822
1823
# File 'lib/google/apis/appengine_v1/classes.rb', line 1815

def update!(**args)
  @check_interval = args[:check_interval] if args.key?(:check_interval)
  @failure_threshold = args[:failure_threshold] if args.key?(:failure_threshold)
  @host = args[:host] if args.key?(:host)
  @initial_delay = args[:initial_delay] if args.key?(:initial_delay)
  @path = args[:path] if args.key?(:path)
  @success_threshold = args[:success_threshold] if args.key?(:success_threshold)
  @timeout = args[:timeout] if args.key?(:timeout)
end