Class: Google::Apis::AppengineV1::ManagedCertificate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

A certificate managed by App Engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedCertificate

Returns a new instance of ManagedCertificate.



1925
1926
1927
# File 'lib/google/apis/appengine_v1/classes.rb', line 1925

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_renewal_timeString

Time at which the certificate was last renewed. The renewal process is fully managed. Certificate renewal will automatically occur before the certificate expires. Renewal errors can be tracked via ManagementStatus.@OutputOnly Corresponds to the JSON property lastRenewalTime

Returns:

  • (String)


1917
1918
1919
# File 'lib/google/apis/appengine_v1/classes.rb', line 1917

def last_renewal_time
  @last_renewal_time
end

#statusString

Status of certificate management. Refers to the most recent certificate acquisition or renewal attempt.@OutputOnly Corresponds to the JSON property status

Returns:

  • (String)


1923
1924
1925
# File 'lib/google/apis/appengine_v1/classes.rb', line 1923

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1930
1931
1932
1933
# File 'lib/google/apis/appengine_v1/classes.rb', line 1930

def update!(**args)
  @last_renewal_time = args[:last_renewal_time] if args.key?(:last_renewal_time)
  @status = args[:status] if args.key?(:status)
end