Class: Google::Apis::AppengineV1::ManualScaling

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

A service with manual scaling runs continuously, allowing you to perform complex initialization and rely on the state of its memory over time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManualScaling

Returns a new instance of ManualScaling.



1948
1949
1950
# File 'lib/google/apis/appengine_v1/classes.rb', line 1948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesFixnum

Number of instances to assign to the service at the start. This number can later be altered by using the Modules API (https://cloud.google.com/appengine/ docs/python/modules/functions) set_num_instances() function. Corresponds to the JSON property instances

Returns:

  • (Fixnum)


1946
1947
1948
# File 'lib/google/apis/appengine_v1/classes.rb', line 1946

def instances
  @instances
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1953
1954
1955
# File 'lib/google/apis/appengine_v1/classes.rb', line 1953

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
end