Class: Google::Apis::AppengineV1::OperationMetadataV1
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::OperationMetadataV1
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
Metadata for the given google.longrunning.Operation.
Instance Attribute Summary collapse
-
#create_version_metadata ⇒ Google::Apis::AppengineV1::CreateVersionMetadataV1
Metadata for the given google.longrunning.Operation during a google.appengine.
-
#end_time ⇒ String
Time that this operation completed.@OutputOnly Corresponds to the JSON property
endTime. -
#ephemeral_message ⇒ String
Ephemeral message that may change every time the operation is polled.
-
#insert_time ⇒ String
Time that this operation was created.@OutputOnly Corresponds to the JSON property
insertTime. -
#method_prop ⇒ String
API method that initiated this operation.
-
#target ⇒ String
Name of the resource that this operation is acting on.
-
#user ⇒ String
User who requested this operation.@OutputOnly Corresponds to the JSON property
user. -
#warning ⇒ Array<String>
Durable messages that persist on every operation poll.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadataV1
constructor
A new instance of OperationMetadataV1.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadataV1
Returns a new instance of OperationMetadataV1.
2200 2201 2202 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2200 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_version_metadata ⇒ Google::Apis::AppengineV1::CreateVersionMetadataV1
Metadata for the given google.longrunning.Operation during a google.appengine.
v1.CreateVersionRequest.
Corresponds to the JSON property createVersionMetadata
2160 2161 2162 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2160 def @create_version_metadata end |
#end_time ⇒ String
Time that this operation completed.@OutputOnly
Corresponds to the JSON property endTime
2165 2166 2167 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2165 def end_time @end_time end |
#ephemeral_message ⇒ String
Ephemeral message that may change every time the operation is polled. @
OutputOnly
Corresponds to the JSON property ephemeralMessage
2171 2172 2173 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2171 def @ephemeral_message end |
#insert_time ⇒ String
Time that this operation was created.@OutputOnly
Corresponds to the JSON property insertTime
2176 2177 2178 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2176 def insert_time @insert_time end |
#method_prop ⇒ String
API method that initiated this operation. Example: google.appengine.v1.
Versions.CreateVersion.@OutputOnly
Corresponds to the JSON property method
2182 2183 2184 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2182 def method_prop @method_prop end |
#target ⇒ String
Name of the resource that this operation is acting on. Example: apps/myapp/
services/default.@OutputOnly
Corresponds to the JSON property target
2188 2189 2190 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2188 def target @target end |
#user ⇒ String
User who requested this operation.@OutputOnly
Corresponds to the JSON property user
2193 2194 2195 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2193 def user @user end |
#warning ⇒ Array<String>
Durable messages that persist on every operation poll. @OutputOnly
Corresponds to the JSON property warning
2198 2199 2200 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2198 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2205 def update!(**args) @create_version_metadata = args[:create_version_metadata] if args.key?(:create_version_metadata) @end_time = args[:end_time] if args.key?(:end_time) @ephemeral_message = args[:ephemeral_message] if args.key?(:ephemeral_message) @insert_time = args[:insert_time] if args.key?(:insert_time) @method_prop = args[:method_prop] if args.key?(:method_prop) @target = args[:target] if args.key?(:target) @user = args[:user] if args.key?(:user) @warning = args[:warning] if args.key?(:warning) end |