Class: Google::Apis::AppengineV1::OperationMetadataV1Beta
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::OperationMetadataV1Beta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
Metadata for the given google.longrunning.Operation.
Instance Attribute Summary collapse
-
#create_version_metadata ⇒ Google::Apis::AppengineV1::CreateVersionMetadataV1Beta
Metadata for the given google.longrunning.Operation during a google.appengine.
-
#end_time ⇒ String
Time that this operation completed.@OutputOnly Corresponds to the JSON property
endTime. -
#ephemeral_message ⇒ String
Ephemeral message that may change every time the operation is polled.
-
#insert_time ⇒ String
Time that this operation was created.@OutputOnly Corresponds to the JSON property
insertTime. -
#method_prop ⇒ String
API method that initiated this operation.
-
#target ⇒ String
Name of the resource that this operation is acting on.
-
#user ⇒ String
User who requested this operation.@OutputOnly Corresponds to the JSON property
user. -
#warning ⇒ Array<String>
Durable messages that persist on every operation poll.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadataV1Beta
constructor
A new instance of OperationMetadataV1Beta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadataV1Beta
Returns a new instance of OperationMetadataV1Beta.
2330 2331 2332 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2330 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_version_metadata ⇒ Google::Apis::AppengineV1::CreateVersionMetadataV1Beta
Metadata for the given google.longrunning.Operation during a google.appengine.
v1beta.CreateVersionRequest.
Corresponds to the JSON property createVersionMetadata
2290 2291 2292 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2290 def @create_version_metadata end |
#end_time ⇒ String
Time that this operation completed.@OutputOnly
Corresponds to the JSON property endTime
2295 2296 2297 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2295 def end_time @end_time end |
#ephemeral_message ⇒ String
Ephemeral message that may change every time the operation is polled. @
OutputOnly
Corresponds to the JSON property ephemeralMessage
2301 2302 2303 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2301 def @ephemeral_message end |
#insert_time ⇒ String
Time that this operation was created.@OutputOnly
Corresponds to the JSON property insertTime
2306 2307 2308 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2306 def insert_time @insert_time end |
#method_prop ⇒ String
API method that initiated this operation. Example: google.appengine.v1beta.
Versions.CreateVersion.@OutputOnly
Corresponds to the JSON property method
2312 2313 2314 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2312 def method_prop @method_prop end |
#target ⇒ String
Name of the resource that this operation is acting on. Example: apps/myapp/
services/default.@OutputOnly
Corresponds to the JSON property target
2318 2319 2320 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2318 def target @target end |
#user ⇒ String
User who requested this operation.@OutputOnly
Corresponds to the JSON property user
2323 2324 2325 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2323 def user @user end |
#warning ⇒ Array<String>
Durable messages that persist on every operation poll. @OutputOnly
Corresponds to the JSON property warning
2328 2329 2330 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2328 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2335 def update!(**args) @create_version_metadata = args[:create_version_metadata] if args.key?(:create_version_metadata) @end_time = args[:end_time] if args.key?(:end_time) @ephemeral_message = args[:ephemeral_message] if args.key?(:ephemeral_message) @insert_time = args[:insert_time] if args.key?(:insert_time) @method_prop = args[:method_prop] if args.key?(:method_prop) @target = args[:target] if args.key?(:target) @user = args[:user] if args.key?(:user) @warning = args[:warning] if args.key?(:warning) end |