Class: Google::Apis::AppengineV1::ProjectEvent
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::ProjectEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
The request sent to CLHs during project events.
Instance Attribute Summary collapse
-
#event_id ⇒ String
The unique ID for this project event.
-
#phase ⇒ String
Phase indicates when in the container event propagation this event is being communicated.
-
#project_metadata ⇒ Google::Apis::AppengineV1::ProjectsMetadata
ProjectsMetadata is the metadata CCFE stores about the all the relevant projects (tenant, consumer, producer).
-
#state ⇒ Google::Apis::AppengineV1::ContainerState
ContainerState contains the externally-visible container state that is used to communicate the state and reasoning for that state to the CLH.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProjectEvent
constructor
A new instance of ProjectEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProjectEvent
Returns a new instance of ProjectEvent.
2378 2379 2380 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2378 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event_id ⇒ String
The unique ID for this project event. CLHs can use this value to dedup
repeated calls. required
Corresponds to the JSON property eventId
2355 2356 2357 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2355 def event_id @event_id end |
#phase ⇒ String
Phase indicates when in the container event propagation this event is being
communicated. Events are sent before and after the per-resource events are
propagated. required
Corresponds to the JSON property phase
2362 2363 2364 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2362 def phase @phase end |
#project_metadata ⇒ Google::Apis::AppengineV1::ProjectsMetadata
ProjectsMetadata is the metadata CCFE stores about the all the relevant
projects (tenant, consumer, producer).
Corresponds to the JSON property projectMetadata
2368 2369 2370 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2368 def @project_metadata end |
#state ⇒ Google::Apis::AppengineV1::ContainerState
ContainerState contains the externally-visible container state that is used to
communicate the state and reasoning for that state to the CLH. This data is
not persisted by CCFE, but is instead derived from CCFE's internal
representation of the container state.
Corresponds to the JSON property state
2376 2377 2378 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2376 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2383 2384 2385 2386 2387 2388 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2383 def update!(**args) @event_id = args[:event_id] if args.key?(:event_id) @phase = args[:phase] if args.key?(:phase) @project_metadata = args[:project_metadata] if args.key?(:project_metadata) @state = args[:state] if args.key?(:state) end |