Class: Google::Apis::AppengineV1::Reasons

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

Containers transition between and within states based on reasons sent from various systems. CCFE will provide the CLH with reasons for the current state per system.The current systems that CCFE supports are: Service Management ( Inception) Data Governance (Wipeout) Abuse (Ares) Billing (Internal Cloud Billing API) Service Activation (Service Controller)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reasons

Returns a new instance of Reasons.



2561
2562
2563
# File 'lib/google/apis/appengine_v1/classes.rb', line 2561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abuseString

Corresponds to the JSON property abuse

Returns:

  • (String)


2537
2538
2539
# File 'lib/google/apis/appengine_v1/classes.rb', line 2537

def abuse
  @abuse
end

#billingString

Corresponds to the JSON property billing

Returns:

  • (String)


2542
2543
2544
# File 'lib/google/apis/appengine_v1/classes.rb', line 2542

def billing
  @billing
end

#data_governanceString

Corresponds to the JSON property dataGovernance

Returns:

  • (String)


2547
2548
2549
# File 'lib/google/apis/appengine_v1/classes.rb', line 2547

def data_governance
  @data_governance
end

#service_activationString

Consumer Container denotes if the service is active within a project or not. This information could be used to clean up resources in case service in DISABLED_FULL i.e. Service is inactive > 30 days. Corresponds to the JSON property serviceActivation

Returns:

  • (String)


2554
2555
2556
# File 'lib/google/apis/appengine_v1/classes.rb', line 2554

def service_activation
  @service_activation
end

#service_managementString

Corresponds to the JSON property serviceManagement

Returns:

  • (String)


2559
2560
2561
# File 'lib/google/apis/appengine_v1/classes.rb', line 2559

def service_management
  @service_management
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2566
2567
2568
2569
2570
2571
2572
# File 'lib/google/apis/appengine_v1/classes.rb', line 2566

def update!(**args)
  @abuse = args[:abuse] if args.key?(:abuse)
  @billing = args[:billing] if args.key?(:billing)
  @data_governance = args[:data_governance] if args.key?(:data_governance)
  @service_activation = args[:service_activation] if args.key?(:service_activation)
  @service_management = args[:service_management] if args.key?(:service_management)
end