Class: Google::Apis::AppengineV1::ResourceEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

The request that is passed to CLH during per-resource events. The request will be sent with update semantics in all cases except for data governance purge events. These events will be sent with delete semantics and the CLH is expected to delete the resource receiving this event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceEvent

Returns a new instance of ResourceEvent.



2640
2641
2642
# File 'lib/google/apis/appengine_v1/classes.rb', line 2640

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_idString

The unique ID for this per-resource event. CLHs can use this value to dedup repeated calls. required Corresponds to the JSON property eventId

Returns:

  • (String)


2625
2626
2627
# File 'lib/google/apis/appengine_v1/classes.rb', line 2625

def event_id
  @event_id
end

#nameString

The name of the resource for which this event is. required Corresponds to the JSON property name

Returns:

  • (String)


2630
2631
2632
# File 'lib/google/apis/appengine_v1/classes.rb', line 2630

def name
  @name
end

#stateGoogle::Apis::AppengineV1::ContainerState

ContainerState contains the externally-visible container state that is used to communicate the state and reasoning for that state to the CLH. This data is not persisted by CCFE, but is instead derived from CCFE's internal representation of the container state. Corresponds to the JSON property state



2638
2639
2640
# File 'lib/google/apis/appengine_v1/classes.rb', line 2638

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2645
2646
2647
2648
2649
# File 'lib/google/apis/appengine_v1/classes.rb', line 2645

def update!(**args)
  @event_id = args[:event_id] if args.key?(:event_id)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end