Class: Google::Apis::AppengineV1::StaticFilesHandler

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

Files served directly to the user for a given URL, such as images, CSS stylesheets, or JavaScript source files. Static file handlers describe which files in the application directory are static files, and which URLs serve them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StaticFilesHandler

Returns a new instance of StaticFilesHandler.



3039
3040
3041
# File 'lib/google/apis/appengine_v1/classes.rb', line 3039

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#application_readableBoolean Also known as: application_readable?

Whether files should also be uploaded as code data. By default, files declared in static file handlers are uploaded as static data and are only served to end users; they cannot be read by the application. If enabled, uploads are charged against both your code and static data storage resource quotas. Corresponds to the JSON property applicationReadable

Returns:

  • (Boolean)


3000
3001
3002
# File 'lib/google/apis/appengine_v1/classes.rb', line 3000

def application_readable
  @application_readable
end

#expirationString

Time a static file served by this handler should be cached by web proxies and browsers. Corresponds to the JSON property expiration

Returns:

  • (String)


3007
3008
3009
# File 'lib/google/apis/appengine_v1/classes.rb', line 3007

def expiration
  @expiration
end

#http_headersHash<String,String>

HTTP headers to use for all responses from these URLs. Corresponds to the JSON property httpHeaders

Returns:

  • (Hash<String,String>)


3012
3013
3014
# File 'lib/google/apis/appengine_v1/classes.rb', line 3012

def http_headers
  @http_headers
end

#mime_typeString

MIME type used to serve all files served by this handler.Defaults to file- specific MIME types, which are derived from each file's filename extension. Corresponds to the JSON property mimeType

Returns:

  • (String)


3018
3019
3020
# File 'lib/google/apis/appengine_v1/classes.rb', line 3018

def mime_type
  @mime_type
end

#pathString

Path to the static files matched by the URL pattern, from the application root directory. The path can refer to text matched in groupings in the URL pattern. Corresponds to the JSON property path

Returns:

  • (String)


3024
3025
3026
# File 'lib/google/apis/appengine_v1/classes.rb', line 3024

def path
  @path
end

#require_matching_fileBoolean Also known as: require_matching_file?

Whether this handler should match the request if the file referenced by the handler does not exist. Corresponds to the JSON property requireMatchingFile

Returns:

  • (Boolean)


3030
3031
3032
# File 'lib/google/apis/appengine_v1/classes.rb', line 3030

def require_matching_file
  @require_matching_file
end

#upload_path_regexString

Regular expression that matches the file paths for all files that should be referenced by this handler. Corresponds to the JSON property uploadPathRegex

Returns:

  • (String)


3037
3038
3039
# File 'lib/google/apis/appengine_v1/classes.rb', line 3037

def upload_path_regex
  @upload_path_regex
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3044
3045
3046
3047
3048
3049
3050
3051
3052
# File 'lib/google/apis/appengine_v1/classes.rb', line 3044

def update!(**args)
  @application_readable = args[:application_readable] if args.key?(:application_readable)
  @expiration = args[:expiration] if args.key?(:expiration)
  @http_headers = args[:http_headers] if args.key?(:http_headers)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @path = args[:path] if args.key?(:path)
  @require_matching_file = args[:require_matching_file] if args.key?(:require_matching_file)
  @upload_path_regex = args[:upload_path_regex] if args.key?(:upload_path_regex)
end