Class: Google::Apis::AppengineV1::UrlDispatchRule
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::UrlDispatchRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
Rules to match an HTTP request and dispatch that request to a service.
Instance Attribute Summary collapse
-
#domain ⇒ String
Domain name to match against.
-
#path ⇒ String
Pathname within the host.
-
#service ⇒ String
Resource ID of a service in this application that should serve the matched request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlDispatchRule
constructor
A new instance of UrlDispatchRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlDispatchRule
Returns a new instance of UrlDispatchRule.
3151 3152 3153 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3151 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
Domain name to match against. The wildcard "" is supported if specified
before a period: ".".Defaults to matching all domains: "*".
Corresponds to the JSON property domain
3136 3137 3138 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3136 def domain @domain end |
#path ⇒ String
Pathname within the host. Must start with a "/". A single "*" can be included
at the end of the path.The sum of the lengths of the domain and path may not
exceed 100 characters.
Corresponds to the JSON property path
3143 3144 3145 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3143 def path @path end |
#service ⇒ String
Resource ID of a service in this application that should serve the matched
request. The service must already exist. Example: default.
Corresponds to the JSON property service
3149 3150 3151 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3149 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3156 3157 3158 3159 3160 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3156 def update!(**args) @domain = args[:domain] if args.key?(:domain) @path = args[:path] if args.key?(:path) @service = args[:service] if args.key?(:service) end |