Class: Google::Apis::AppengineV1::AuthorizedCertificate
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::AuthorizedCertificate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
An SSL certificate that a user has been authorized to administer. A user is authorized to administer any certificate that applies to one of their authorized domains.
Instance Attribute Summary collapse
-
#certificate_raw_data ⇒ Google::Apis::AppengineV1::CertificateRawData
An SSL certificate obtained from a certificate authority.
-
#display_name ⇒ String
The user-specified display name of the certificate.
-
#domain_mappings_count ⇒ Fixnum
Aggregate count of the domain mappings with this certificate mapped.
-
#domain_names ⇒ Array<String>
Output only.
-
#expire_time ⇒ String
The time when this certificate expires.
-
#id ⇒ String
Output only.
-
#managed_certificate ⇒ Google::Apis::AppengineV1::ManagedCertificate
A certificate managed by App Engine.
-
#name ⇒ String
Output only.
-
#visible_domain_mappings ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuthorizedCertificate
constructor
A new instance of AuthorizedCertificate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuthorizedCertificate
Returns a new instance of AuthorizedCertificate.
293 294 295 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 293 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_raw_data ⇒ Google::Apis::AppengineV1::CertificateRawData
An SSL certificate obtained from a certificate authority.
Corresponds to the JSON property certificateRawData
234 235 236 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 234 def certificate_raw_data @certificate_raw_data end |
#display_name ⇒ String
The user-specified display name of the certificate. This is not guaranteed to
be unique. Example: My Certificate.
Corresponds to the JSON property displayName
240 241 242 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 240 def display_name @display_name end |
#domain_mappings_count ⇒ Fixnum
Aggregate count of the domain mappings with this certificate mapped. This
count includes domain mappings on applications for which the user does not
have VIEWER permissions.Only returned by GET or LIST requests when
specifically requested by the view=FULL_CERTIFICATE option.@OutputOnly
Corresponds to the JSON property domainMappingsCount
248 249 250 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 248 def domain_mappings_count @domain_mappings_count end |
#domain_names ⇒ Array<String>
Output only. Topmost applicable domains of this certificate. This certificate
applies to these domains and their subdomains. Example: example.com.@
OutputOnly
Corresponds to the JSON property domainNames
255 256 257 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 255 def domain_names @domain_names end |
#expire_time ⇒ String
The time when this certificate expires. To update the renewal time on this
certificate, upload an SSL certificate with a different expiration time using
AuthorizedCertificates.UpdateAuthorizedCertificate.@OutputOnly
Corresponds to the JSON property expireTime
262 263 264 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 262 def expire_time @expire_time end |
#id ⇒ String
Output only. Relative name of the certificate. This is a unique value
autogenerated on AuthorizedCertificate resource creation. Example: 12345.@
OutputOnly
Corresponds to the JSON property id
269 270 271 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 269 def id @id end |
#managed_certificate ⇒ Google::Apis::AppengineV1::ManagedCertificate
A certificate managed by App Engine.
Corresponds to the JSON property managedCertificate
274 275 276 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 274 def managed_certificate @managed_certificate end |
#name ⇒ String
Output only. Full path to the AuthorizedCertificate resource in the API.
Example: apps/myapp/authorizedCertificates/12345.@OutputOnly
Corresponds to the JSON property name
280 281 282 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 280 def name @name end |
#visible_domain_mappings ⇒ Array<String>
Output only. The full paths to user visible Domain Mapping resources that have
this certificate mapped. Example: apps/myapp/domainMappings/example.com.This
may not represent the full list of mapped domain mappings if the user does not
have VIEWER permissions on all of the applications that have this certificate
mapped. See domain_mappings_count for a complete count.Only returned by GET or
LIST requests when specifically requested by the view=FULL_CERTIFICATE option.@
OutputOnly
Corresponds to the JSON property visibleDomainMappings
291 292 293 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 291 def visible_domain_mappings @visible_domain_mappings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 298 def update!(**args) @certificate_raw_data = args[:certificate_raw_data] if args.key?(:certificate_raw_data) @display_name = args[:display_name] if args.key?(:display_name) @domain_mappings_count = args[:domain_mappings_count] if args.key?(:domain_mappings_count) @domain_names = args[:domain_names] if args.key?(:domain_names) @expire_time = args[:expire_time] if args.key?(:expire_time) @id = args[:id] if args.key?(:id) @managed_certificate = args[:managed_certificate] if args.key?(:managed_certificate) @name = args[:name] if args.key?(:name) @visible_domain_mappings = args[:visible_domain_mappings] if args.key?(:visible_domain_mappings) end |