Class: Google::Apis::AppengineV1::FirewallRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

A single firewall rule that is evaluated against incoming traffic and provides an action to take on matched requests. A positive integer between 1, Int32. MaxValue-1 that defines the order of rule evaluation. Rules with the lowest priority are evaluated first.A default rule at priority Int32.MaxValue matches all IPv4 and IPv6 traffic when no previous rule matches. Only the action of this rule can be modified by the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallRule

Returns a new instance of FirewallRule.



1161
1162
1163
# File 'lib/google/apis/appengine_v1/classes.rb', line 1161

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

The action to take on matched requests. Corresponds to the JSON property action

Returns:

  • (String)


1137
1138
1139
# File 'lib/google/apis/appengine_v1/classes.rb', line 1137

def action
  @action
end

#descriptionString

An optional string description of this rule. This field has a maximum length of 400 characters. Corresponds to the JSON property description

Returns:

  • (String)


1143
1144
1145
# File 'lib/google/apis/appengine_v1/classes.rb', line 1143

def description
  @description
end

#priorityFixnum

Corresponds to the JSON property priority

Returns:

  • (Fixnum)


1148
1149
1150
# File 'lib/google/apis/appengine_v1/classes.rb', line 1148

def priority
  @priority
end

#source_rangeString

IP address or range, defined using CIDR notation, of requests that this rule applies to. You can use the wildcard character "*" to match all IPs equivalent to "0/0" and "::/0" together. Examples: 192.168.1.1 or 192.168.0.0/16 or 2001: db8::/32 or 2001:0db8:0000:0042:0000:8a2e:0370:7334. Truncation will be silently performed on addresses which are not properly truncated. For example, 1.2.3.4/24 is accepted as the same address as 1.2.3.0/24. Similarly, for IPv6, 2001:db8::1/32 is accepted as the same address as 2001:db8::/32. Corresponds to the JSON property sourceRange

Returns:

  • (String)


1159
1160
1161
# File 'lib/google/apis/appengine_v1/classes.rb', line 1159

def source_range
  @source_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1166
1167
1168
1169
1170
1171
# File 'lib/google/apis/appengine_v1/classes.rb', line 1166

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @description = args[:description] if args.key?(:description)
  @priority = args[:priority] if args.key?(:priority)
  @source_range = args[:source_range] if args.key?(:source_range)
end