Class: Google::Apis::AppengineV1::Instance
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::Instance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
An Instance resource is the computing unit that App Engine uses to automatically scale an application.
Instance Attribute Summary collapse
-
#app_engine_release ⇒ String
Output only.
-
#availability ⇒ String
Output only.
-
#average_latency ⇒ Fixnum
Output only.
-
#errors ⇒ Fixnum
Output only.
-
#id ⇒ String
Output only.
-
#memory_usage ⇒ Fixnum
Output only.
-
#name ⇒ String
Output only.
-
#qps ⇒ Float
Output only.
-
#requests ⇒ Fixnum
Output only.
-
#start_time ⇒ String
Output only.
-
#vm_debug_enabled ⇒ Boolean
(also: #vm_debug_enabled?)
Output only.
-
#vm_id ⇒ String
Output only.
-
#vm_ip ⇒ String
Output only.
-
#vm_liveness ⇒ String
Output only.
-
#vm_name ⇒ String
Output only.
-
#vm_status ⇒ String
Output only.
-
#vm_zone_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Instance
constructor
A new instance of Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Instance
Returns a new instance of Instance.
1465 1466 1467 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1465 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_engine_release ⇒ String
Output only. App Engine release this instance is running on.
Corresponds to the JSON property appEngineRelease
1373 1374 1375 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1373 def app_engine_release @app_engine_release end |
#availability ⇒ String
Output only. Availability of the instance.
Corresponds to the JSON property availability
1378 1379 1380 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1378 def availability @availability end |
#average_latency ⇒ Fixnum
Output only. Average latency (ms) over the last minute.
Corresponds to the JSON property averageLatency
1383 1384 1385 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1383 def average_latency @average_latency end |
#errors ⇒ Fixnum
Output only. Number of errors since this instance was started.
Corresponds to the JSON property errors
1388 1389 1390 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1388 def errors @errors end |
#id ⇒ String
Output only. Relative name of the instance within the version. Example:
instance-1.
Corresponds to the JSON property id
1394 1395 1396 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1394 def id @id end |
#memory_usage ⇒ Fixnum
Output only. Total memory in use (bytes).
Corresponds to the JSON property memoryUsage
1399 1400 1401 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1399 def memory_usage @memory_usage end |
#name ⇒ String
Output only. Full path to the Instance resource in the API. Example: apps/
myapp/services/default/versions/v1/instances/instance-1.
Corresponds to the JSON property name
1405 1406 1407 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1405 def name @name end |
#qps ⇒ Float
Output only. Average queries per second (QPS) over the last minute.
Corresponds to the JSON property qps
1410 1411 1412 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1410 def qps @qps end |
#requests ⇒ Fixnum
Output only. Number of requests since this instance was started.
Corresponds to the JSON property requests
1415 1416 1417 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1415 def requests @requests end |
#start_time ⇒ String
Output only. Time that this instance was started.@OutputOnly
Corresponds to the JSON property startTime
1420 1421 1422 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1420 def start_time @start_time end |
#vm_debug_enabled ⇒ Boolean Also known as: vm_debug_enabled?
Output only. Whether this instance is in debug mode. Only applicable for
instances in App Engine flexible environment.
Corresponds to the JSON property vmDebugEnabled
1426 1427 1428 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1426 def vm_debug_enabled @vm_debug_enabled end |
#vm_id ⇒ String
Output only. Virtual machine ID of this instance. Only applicable for
instances in App Engine flexible environment.
Corresponds to the JSON property vmId
1433 1434 1435 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1433 def vm_id @vm_id end |
#vm_ip ⇒ String
Output only. The IP address of this instance. Only applicable for instances in
App Engine flexible environment.
Corresponds to the JSON property vmIp
1439 1440 1441 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1439 def vm_ip @vm_ip end |
#vm_liveness ⇒ String
Output only. The liveness health check of this instance. Only applicable for
instances in App Engine flexible environment.
Corresponds to the JSON property vmLiveness
1445 1446 1447 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1445 def vm_liveness @vm_liveness end |
#vm_name ⇒ String
Output only. Name of the virtual machine where this instance lives. Only
applicable for instances in App Engine flexible environment.
Corresponds to the JSON property vmName
1451 1452 1453 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1451 def vm_name @vm_name end |
#vm_status ⇒ String
Output only. Status of the virtual machine where this instance lives. Only
applicable for instances in App Engine flexible environment.
Corresponds to the JSON property vmStatus
1457 1458 1459 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1457 def vm_status @vm_status end |
#vm_zone_name ⇒ String
Output only. Zone where the virtual machine is located. Only applicable for
instances in App Engine flexible environment.
Corresponds to the JSON property vmZoneName
1463 1464 1465 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1463 def vm_zone_name @vm_zone_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1470 def update!(**args) @app_engine_release = args[:app_engine_release] if args.key?(:app_engine_release) @availability = args[:availability] if args.key?(:availability) @average_latency = args[:average_latency] if args.key?(:average_latency) @errors = args[:errors] if args.key?(:errors) @id = args[:id] if args.key?(:id) @memory_usage = args[:memory_usage] if args.key?(:memory_usage) @name = args[:name] if args.key?(:name) @qps = args[:qps] if args.key?(:qps) @requests = args[:requests] if args.key?(:requests) @start_time = args[:start_time] if args.key?(:start_time) @vm_debug_enabled = args[:vm_debug_enabled] if args.key?(:vm_debug_enabled) @vm_id = args[:vm_id] if args.key?(:vm_id) @vm_ip = args[:vm_ip] if args.key?(:vm_ip) @vm_liveness = args[:vm_liveness] if args.key?(:vm_liveness) @vm_name = args[:vm_name] if args.key?(:vm_name) @vm_status = args[:vm_status] if args.key?(:vm_status) @vm_zone_name = args[:vm_zone_name] if args.key?(:vm_zone_name) end |