Class: Google::Apis::AppengineV1::ManagedCertificate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

A certificate managed by App Engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedCertificate

Returns a new instance of ManagedCertificate.



1932
1933
1934
# File 'lib/google/apis/appengine_v1/classes.rb', line 1932

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_renewal_timeString

Time at which the certificate was last renewed. The renewal process is fully managed. Certificate renewal will automatically occur before the certificate expires. Renewal errors can be tracked via ManagementStatus.@OutputOnly Corresponds to the JSON property lastRenewalTime

Returns:

  • (String)


1924
1925
1926
# File 'lib/google/apis/appengine_v1/classes.rb', line 1924

def last_renewal_time
  @last_renewal_time
end

#statusString

Status of certificate management. Refers to the most recent certificate acquisition or renewal attempt.@OutputOnly Corresponds to the JSON property status

Returns:

  • (String)


1930
1931
1932
# File 'lib/google/apis/appengine_v1/classes.rb', line 1930

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1937
1938
1939
1940
# File 'lib/google/apis/appengine_v1/classes.rb', line 1937

def update!(**args)
  @last_renewal_time = args[:last_renewal_time] if args.key?(:last_renewal_time)
  @status = args[:status] if args.key?(:status)
end