Class: Google::Apis::AppengineV1::Network
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::Network
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
Extra network settings. Only applicable in the App Engine flexible environment.
Instance Attribute Summary collapse
-
#forwarded_ports ⇒ Array<String>
List of ports, or port pairs, to forward from the virtual machine to the application container.
-
#instance_ip_mode ⇒ String
The IP mode for instances.
-
#instance_tag ⇒ String
Tag to apply to the instance during creation.
-
#name ⇒ String
Google Compute Engine network where the virtual machines are created.
-
#session_affinity ⇒ Boolean
(also: #session_affinity?)
Enable session affinity.
-
#subnetwork_name ⇒ String
Google Cloud Platform sub-network where the virtual machines are created.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Network
constructor
A new instance of Network.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Network
Returns a new instance of Network.
2017 2018 2019 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#forwarded_ports ⇒ Array<String>
List of ports, or port pairs, to forward from the virtual machine to the
application container. Only applicable in the App Engine flexible environment.
Corresponds to the JSON property forwardedPorts
1973 1974 1975 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1973 def forwarded_ports @forwarded_ports end |
#instance_ip_mode ⇒ String
The IP mode for instances. Only applicable in the App Engine flexible
environment.
Corresponds to the JSON property instanceIpMode
1979 1980 1981 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1979 def instance_ip_mode @instance_ip_mode end |
#instance_tag ⇒ String
Tag to apply to the instance during creation. Only applicable in the App
Engine flexible environment.
Corresponds to the JSON property instanceTag
1985 1986 1987 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1985 def instance_tag @instance_tag end |
#name ⇒ String
Google Compute Engine network where the virtual machines are created. Specify
the short name, not the resource path.Defaults to default.
Corresponds to the JSON property name
1991 1992 1993 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1991 def name @name end |
#session_affinity ⇒ Boolean Also known as: session_affinity?
Enable session affinity. Only applicable in the App Engine flexible
environment.
Corresponds to the JSON property sessionAffinity
1997 1998 1999 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 1997 def session_affinity @session_affinity end |
#subnetwork_name ⇒ String
Google Cloud Platform sub-network where the virtual machines are created.
Specify the short name, not the resource path.If a subnetwork name is
specified, a network name will also be required unless it is for the default
network. If the network that the instance is being created in is a Legacy
network, then the IP address is allocated from the IPv4Range. If the network
that the instance is being created in is an auto Subnet Mode Network, then
only network name should be specified (not the subnetwork_name) and the IP
address is created from the IPCidrRange of the subnetwork that exists in that
zone for that network. If the network that the instance is being created in is
a custom Subnet Mode Network, then the subnetwork_name must be specified and
the IP address is created from the IPCidrRange of the subnetwork.If specified,
the subnetwork must exist in the same region as the App Engine flexible
environment application.
Corresponds to the JSON property subnetworkName
2015 2016 2017 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2015 def subnetwork_name @subnetwork_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2022 2023 2024 2025 2026 2027 2028 2029 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2022 def update!(**args) @forwarded_ports = args[:forwarded_ports] if args.key?(:forwarded_ports) @instance_ip_mode = args[:instance_ip_mode] if args.key?(:instance_ip_mode) @instance_tag = args[:instance_tag] if args.key?(:instance_tag) @name = args[:name] if args.key?(:name) @session_affinity = args[:session_affinity] if args.key?(:session_affinity) @subnetwork_name = args[:subnetwork_name] if args.key?(:subnetwork_name) end |