Class: Google::Apis::AppengineV1::Reasons
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::Reasons
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
Containers transition between and within states based on reasons sent from various systems. CCFE will provide the CLH with reasons for the current state per system.The current systems that CCFE supports are: Service Management ( Inception) Data Governance (Wipeout) Abuse (Ares) Billing (Internal Cloud Billing API) Service Activation (Service Controller)
Instance Attribute Summary collapse
-
#abuse ⇒ String
Corresponds to the JSON property
abuse. -
#billing ⇒ String
Corresponds to the JSON property
billing. -
#data_governance ⇒ String
Corresponds to the JSON property
dataGovernance. -
#service_activation ⇒ String
Consumer Container denotes if the service is active within a project or not.
-
#service_management ⇒ String
Corresponds to the JSON property
serviceManagement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Reasons
constructor
A new instance of Reasons.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Reasons
Returns a new instance of Reasons.
2561 2562 2563 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2561 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abuse ⇒ String
Corresponds to the JSON property abuse
2537 2538 2539 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2537 def abuse @abuse end |
#billing ⇒ String
Corresponds to the JSON property billing
2542 2543 2544 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2542 def billing @billing end |
#data_governance ⇒ String
Corresponds to the JSON property dataGovernance
2547 2548 2549 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2547 def data_governance @data_governance end |
#service_activation ⇒ String
Consumer Container denotes if the service is active within a project or not.
This information could be used to clean up resources in case service in
DISABLED_FULL i.e. Service is inactive > 30 days.
Corresponds to the JSON property serviceActivation
2554 2555 2556 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2554 def service_activation @service_activation end |
#service_management ⇒ String
Corresponds to the JSON property serviceManagement
2559 2560 2561 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2559 def service_management @service_management end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2566 2567 2568 2569 2570 2571 2572 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2566 def update!(**args) @abuse = args[:abuse] if args.key?(:abuse) @billing = args[:billing] if args.key?(:billing) @data_governance = args[:data_governance] if args.key?(:data_governance) @service_activation = args[:service_activation] if args.key?(:service_activation) @service_management = args[:service_management] if args.key?(:service_management) end |