Class: Google::Apis::AppengineV1::Reasons
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::Reasons
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
Containers transition between and within states based on reasons sent from various systems. CCFE will provide the CLH with reasons for the current state per system.The current systems that CCFE supports are: Service Management ( Inception) Data Governance (Wipeout) Abuse (Ares) Billing (Internal Cloud Billing API) Service Activation (Service Controller)
Instance Attribute Summary collapse
-
#abuse ⇒ String
Corresponds to the JSON property
abuse. -
#billing ⇒ String
Corresponds to the JSON property
billing. -
#data_governance ⇒ String
Corresponds to the JSON property
dataGovernance. -
#service_activation ⇒ String
Consumer Container denotes if the service is active within a project or not.
-
#service_management ⇒ String
Corresponds to the JSON property
serviceManagement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Reasons
constructor
A new instance of Reasons.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Reasons
Returns a new instance of Reasons.
2558 2559 2560 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abuse ⇒ String
Corresponds to the JSON property abuse
2534 2535 2536 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2534 def abuse @abuse end |
#billing ⇒ String
Corresponds to the JSON property billing
2539 2540 2541 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2539 def billing @billing end |
#data_governance ⇒ String
Corresponds to the JSON property dataGovernance
2544 2545 2546 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2544 def data_governance @data_governance end |
#service_activation ⇒ String
Consumer Container denotes if the service is active within a project or not.
This information could be used to clean up resources in case service in
DISABLED_FULL i.e. Service is inactive > 30 days.
Corresponds to the JSON property serviceActivation
2551 2552 2553 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2551 def service_activation @service_activation end |
#service_management ⇒ String
Corresponds to the JSON property serviceManagement
2556 2557 2558 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2556 def service_management @service_management end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2563 2564 2565 2566 2567 2568 2569 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2563 def update!(**args) @abuse = args[:abuse] if args.key?(:abuse) @billing = args[:billing] if args.key?(:billing) @data_governance = args[:data_governance] if args.key?(:data_governance) @service_activation = args[:service_activation] if args.key?(:service_activation) @service_management = args[:service_management] if args.key?(:service_management) end |