Class: Google::Apis::AppengineV1::ResourceEvent
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::ResourceEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
The request that is passed to CLH during per-resource events. The request will be sent with update semantics in all cases except for data governance purge events. These events will be sent with delete semantics and the CLH is expected to delete the resource receiving this event.
Instance Attribute Summary collapse
-
#event_id ⇒ String
The unique ID for this per-resource event.
-
#name ⇒ String
The name of the resource for which this event is.
-
#state ⇒ Google::Apis::AppengineV1::ContainerState
ContainerState contains the externally-visible container state that is used to communicate the state and reasoning for that state to the CLH.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceEvent
constructor
A new instance of ResourceEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceEvent
Returns a new instance of ResourceEvent.
2637 2638 2639 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event_id ⇒ String
The unique ID for this per-resource event. CLHs can use this value to dedup
repeated calls. required
Corresponds to the JSON property eventId
2622 2623 2624 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2622 def event_id @event_id end |
#name ⇒ String
The name of the resource for which this event is. required
Corresponds to the JSON property name
2627 2628 2629 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2627 def name @name end |
#state ⇒ Google::Apis::AppengineV1::ContainerState
ContainerState contains the externally-visible container state that is used to
communicate the state and reasoning for that state to the CLH. This data is
not persisted by CCFE, but is instead derived from CCFE's internal
representation of the container state.
Corresponds to the JSON property state
2635 2636 2637 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2635 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2642 2643 2644 2645 2646 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2642 def update!(**args) @event_id = args[:event_id] if args.key?(:event_id) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |