Class: Google::Apis::AppengineV1::Resources
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::Resources
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
Machine resources for a version.
Instance Attribute Summary collapse
-
#cpu ⇒ Float
Number of CPU cores needed.
-
#disk_gb ⇒ Float
Disk size (GB) needed.
-
#kms_key_reference ⇒ String
The name of the encryption key that is stored in Google Cloud KMS.
-
#memory_gb ⇒ Float
Memory (GB) needed.
-
#volumes ⇒ Array<Google::Apis::AppengineV1::Volume>
User specified volumes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Resources
constructor
A new instance of Resources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Resources
Returns a new instance of Resources.
2715 2716 2717 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2715 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpu ⇒ Float
Number of CPU cores needed.
Corresponds to the JSON property cpu
2692 2693 2694 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2692 def cpu @cpu end |
#disk_gb ⇒ Float
Disk size (GB) needed.
Corresponds to the JSON property diskGb
2697 2698 2699 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2697 def disk_gb @disk_gb end |
#kms_key_reference ⇒ String
The name of the encryption key that is stored in Google Cloud KMS. Only should
be used by Cloud Composer to encrypt the vm disk
Corresponds to the JSON property kmsKeyReference
2703 2704 2705 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2703 def kms_key_reference @kms_key_reference end |
#memory_gb ⇒ Float
Memory (GB) needed.
Corresponds to the JSON property memoryGb
2708 2709 2710 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2708 def memory_gb @memory_gb end |
#volumes ⇒ Array<Google::Apis::AppengineV1::Volume>
User specified volumes.
Corresponds to the JSON property volumes
2713 2714 2715 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2713 def volumes @volumes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2720 def update!(**args) @cpu = args[:cpu] if args.key?(:cpu) @disk_gb = args[:disk_gb] if args.key?(:disk_gb) @kms_key_reference = args[:kms_key_reference] if args.key?(:kms_key_reference) @memory_gb = args[:memory_gb] if args.key?(:memory_gb) @volumes = args[:volumes] if args.key?(:volumes) end |