Class: Google::Apis::AppengineV1::Resources

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

Machine resources for a version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Resources

Returns a new instance of Resources.



2712
2713
2714
# File 'lib/google/apis/appengine_v1/classes.rb', line 2712

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpuFloat

Number of CPU cores needed. Corresponds to the JSON property cpu

Returns:

  • (Float)


2689
2690
2691
# File 'lib/google/apis/appengine_v1/classes.rb', line 2689

def cpu
  @cpu
end

#disk_gbFloat

Disk size (GB) needed. Corresponds to the JSON property diskGb

Returns:

  • (Float)


2694
2695
2696
# File 'lib/google/apis/appengine_v1/classes.rb', line 2694

def disk_gb
  @disk_gb
end

#kms_key_referenceString

The name of the encryption key that is stored in Google Cloud KMS. Only should be used by Cloud Composer to encrypt the vm disk Corresponds to the JSON property kmsKeyReference

Returns:

  • (String)


2700
2701
2702
# File 'lib/google/apis/appengine_v1/classes.rb', line 2700

def kms_key_reference
  @kms_key_reference
end

#memory_gbFloat

Memory (GB) needed. Corresponds to the JSON property memoryGb

Returns:

  • (Float)


2705
2706
2707
# File 'lib/google/apis/appengine_v1/classes.rb', line 2705

def memory_gb
  @memory_gb
end

#volumesArray<Google::Apis::AppengineV1::Volume>

User specified volumes. Corresponds to the JSON property volumes



2710
2711
2712
# File 'lib/google/apis/appengine_v1/classes.rb', line 2710

def volumes
  @volumes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2717
2718
2719
2720
2721
2722
2723
# File 'lib/google/apis/appengine_v1/classes.rb', line 2717

def update!(**args)
  @cpu = args[:cpu] if args.key?(:cpu)
  @disk_gb = args[:disk_gb] if args.key?(:disk_gb)
  @kms_key_reference = args[:kms_key_reference] if args.key?(:kms_key_reference)
  @memory_gb = args[:memory_gb] if args.key?(:memory_gb)
  @volumes = args[:volumes] if args.key?(:volumes)
end