Class: Google::Apis::AppengineV1::SslSettings
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::SslSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
SSL configuration for a DomainMapping resource.
Instance Attribute Summary collapse
-
#certificate_id ⇒ String
ID of the AuthorizedCertificate resource configuring SSL for the application.
-
#pending_managed_certificate_id ⇒ String
Output only.
-
#ssl_management_type ⇒ String
SSL management type for this domain.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslSettings
constructor
A new instance of SslSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslSettings
Returns a new instance of SslSettings.
2934 2935 2936 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2934 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_id ⇒ String
ID of the AuthorizedCertificate resource configuring SSL for the application.
Clearing this field will remove SSL support.By default, a managed certificate
is automatically created for every domain mapping. To omit SSL support or to
configure SSL manually, specify SslManagementType.MANUAL on a CREATE or UPDATE
request. You must be authorized to administer the AuthorizedCertificate
resource to manually map it to a DomainMapping resource. Example: 12345.
Corresponds to the JSON property certificateId
2914 2915 2916 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2914 def certificate_id @certificate_id end |
#pending_managed_certificate_id ⇒ String
Output only. ID of the managed AuthorizedCertificate resource currently being
provisioned, if applicable. Until the new managed certificate has been
successfully provisioned, the previous SSL state will be preserved. Once the
provisioning process completes, the certificate_id field will reflect the new
managed certificate and this field will be left empty. To remove SSL support
while there is still a pending managed certificate, clear the certificate_id
field with an UpdateDomainMappingRequest.@OutputOnly
Corresponds to the JSON property pendingManagedCertificateId
2925 2926 2927 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2925 def pending_managed_certificate_id @pending_managed_certificate_id end |
#ssl_management_type ⇒ String
SSL management type for this domain. If AUTOMATIC, a managed certificate is
automatically provisioned. If MANUAL, certificate_id must be manually
specified in order to configure SSL for this domain.
Corresponds to the JSON property sslManagementType
2932 2933 2934 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2932 def ssl_management_type @ssl_management_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2939 2940 2941 2942 2943 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 2939 def update!(**args) @certificate_id = args[:certificate_id] if args.key?(:certificate_id) @pending_managed_certificate_id = args[:pending_managed_certificate_id] if args.key?(:pending_managed_certificate_id) @ssl_management_type = args[:ssl_management_type] if args.key?(:ssl_management_type) end |