Class: Google::Apis::AppengineV1::StaticFilesHandler

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

Files served directly to the user for a given URL, such as images, CSS stylesheets, or JavaScript source files. Static file handlers describe which files in the application directory are static files, and which URLs serve them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StaticFilesHandler

Returns a new instance of StaticFilesHandler.



3036
3037
3038
# File 'lib/google/apis/appengine_v1/classes.rb', line 3036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#application_readableBoolean Also known as: application_readable?

Whether files should also be uploaded as code data. By default, files declared in static file handlers are uploaded as static data and are only served to end users; they cannot be read by the application. If enabled, uploads are charged against both your code and static data storage resource quotas. Corresponds to the JSON property applicationReadable

Returns:

  • (Boolean)


2997
2998
2999
# File 'lib/google/apis/appengine_v1/classes.rb', line 2997

def application_readable
  @application_readable
end

#expirationString

Time a static file served by this handler should be cached by web proxies and browsers. Corresponds to the JSON property expiration

Returns:

  • (String)


3004
3005
3006
# File 'lib/google/apis/appengine_v1/classes.rb', line 3004

def expiration
  @expiration
end

#http_headersHash<String,String>

HTTP headers to use for all responses from these URLs. Corresponds to the JSON property httpHeaders

Returns:

  • (Hash<String,String>)


3009
3010
3011
# File 'lib/google/apis/appengine_v1/classes.rb', line 3009

def http_headers
  @http_headers
end

#mime_typeString

MIME type used to serve all files served by this handler.Defaults to file- specific MIME types, which are derived from each file's filename extension. Corresponds to the JSON property mimeType

Returns:

  • (String)


3015
3016
3017
# File 'lib/google/apis/appengine_v1/classes.rb', line 3015

def mime_type
  @mime_type
end

#pathString

Path to the static files matched by the URL pattern, from the application root directory. The path can refer to text matched in groupings in the URL pattern. Corresponds to the JSON property path

Returns:

  • (String)


3021
3022
3023
# File 'lib/google/apis/appengine_v1/classes.rb', line 3021

def path
  @path
end

#require_matching_fileBoolean Also known as: require_matching_file?

Whether this handler should match the request if the file referenced by the handler does not exist. Corresponds to the JSON property requireMatchingFile

Returns:

  • (Boolean)


3027
3028
3029
# File 'lib/google/apis/appengine_v1/classes.rb', line 3027

def require_matching_file
  @require_matching_file
end

#upload_path_regexString

Regular expression that matches the file paths for all files that should be referenced by this handler. Corresponds to the JSON property uploadPathRegex

Returns:

  • (String)


3034
3035
3036
# File 'lib/google/apis/appengine_v1/classes.rb', line 3034

def upload_path_regex
  @upload_path_regex
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3041
3042
3043
3044
3045
3046
3047
3048
3049
# File 'lib/google/apis/appengine_v1/classes.rb', line 3041

def update!(**args)
  @application_readable = args[:application_readable] if args.key?(:application_readable)
  @expiration = args[:expiration] if args.key?(:expiration)
  @http_headers = args[:http_headers] if args.key?(:http_headers)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @path = args[:path] if args.key?(:path)
  @require_matching_file = args[:require_matching_file] if args.key?(:require_matching_file)
  @upload_path_regex = args[:upload_path_regex] if args.key?(:upload_path_regex)
end