Class: Google::Apis::AppengineV1::UrlMap
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::UrlMap
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
URL pattern and description of how the URL should be handled. App Engine can handle URLs by executing application code or by serving static files uploaded with the version, such as images, CSS, or JavaScript.
Instance Attribute Summary collapse
-
#api_endpoint ⇒ Google::Apis::AppengineV1::ApiEndpointHandler
Uses Google Cloud Endpoints to handle requests.
-
#auth_fail_action ⇒ String
Action to take when users access resources that require authentication.
-
#login ⇒ String
Level of login required to access this resource.
-
#redirect_http_response_code ⇒ String
30x code to use when performing redirects for the secure field.
-
#script ⇒ Google::Apis::AppengineV1::ScriptHandler
Executes a script to handle the request that matches the URL pattern.
-
#security_level ⇒ String
Security (HTTPS) enforcement for this URL.
-
#static_files ⇒ Google::Apis::AppengineV1::StaticFilesHandler
Files served directly to the user for a given URL, such as images, CSS stylesheets, or JavaScript source files.
-
#url_regex ⇒ String
URL prefix.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMap
constructor
A new instance of UrlMap.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMap
Returns a new instance of UrlMap.
3214 3215 3216 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3214 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_endpoint ⇒ Google::Apis::AppengineV1::ApiEndpointHandler
Uses Google Cloud Endpoints to handle requests.
Corresponds to the JSON property apiEndpoint
3169 3170 3171 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3169 def api_endpoint @api_endpoint end |
#auth_fail_action ⇒ String
Action to take when users access resources that require authentication.
Defaults to redirect.
Corresponds to the JSON property authFailAction
3175 3176 3177 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3175 def auth_fail_action @auth_fail_action end |
#login ⇒ String
Level of login required to access this resource. Not supported for Node.js in
the App Engine standard environment.
Corresponds to the JSON property login
3181 3182 3183 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3181 def login @login end |
#redirect_http_response_code ⇒ String
30x code to use when performing redirects for the secure field. Defaults to
302.
Corresponds to the JSON property redirectHttpResponseCode
3187 3188 3189 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3187 def redirect_http_response_code @redirect_http_response_code end |
#script ⇒ Google::Apis::AppengineV1::ScriptHandler
Executes a script to handle the request that matches the URL pattern.
Corresponds to the JSON property script
3192 3193 3194 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3192 def script @script end |
#security_level ⇒ String
Security (HTTPS) enforcement for this URL.
Corresponds to the JSON property securityLevel
3197 3198 3199 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3197 def security_level @security_level end |
#static_files ⇒ Google::Apis::AppengineV1::StaticFilesHandler
Files served directly to the user for a given URL, such as images, CSS
stylesheets, or JavaScript source files. Static file handlers describe which
files in the application directory are static files, and which URLs serve them.
Corresponds to the JSON property staticFiles
3204 3205 3206 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3204 def static_files @static_files end |
#url_regex ⇒ String
URL prefix. Uses regular expression syntax, which means regexp special
characters must be escaped, but should not contain groupings. All URLs that
begin with this prefix are handled by this handler, using the portion of the
URL after the prefix as part of the file path.
Corresponds to the JSON property urlRegex
3212 3213 3214 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3212 def url_regex @url_regex end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3219 3220 3221 3222 3223 3224 3225 3226 3227 3228 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3219 def update!(**args) @api_endpoint = args[:api_endpoint] if args.key?(:api_endpoint) @auth_fail_action = args[:auth_fail_action] if args.key?(:auth_fail_action) @login = args[:login] if args.key?(:login) @redirect_http_response_code = args[:redirect_http_response_code] if args.key?(:redirect_http_response_code) @script = args[:script] if args.key?(:script) @security_level = args[:security_level] if args.key?(:security_level) @static_files = args[:static_files] if args.key?(:static_files) @url_regex = args[:url_regex] if args.key?(:url_regex) end |