Class: Google::Apis::AppengineV1::Version
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1::Version
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb
Overview
A Version resource is a specific set of source code and configuration files that are deployed into a service.
Instance Attribute Summary collapse
-
#api_config ⇒ Google::Apis::AppengineV1::ApiConfigHandler
Google Cloud Endpoints (https://cloud.google.com/endpoints) configuration for API handlers.
-
#app_engine_apis ⇒ Boolean
(also: #app_engine_apis?)
Allows App Engine second generation runtimes to access the legacy bundled services.
-
#app_engine_bundled_services ⇒ Array<String>
List of specific App Engine Bundled Services that are enabled for this Version.
-
#automatic_scaling ⇒ Google::Apis::AppengineV1::AutomaticScaling
Automatic scaling is based on request rate, response latencies, and other application metrics.
-
#basic_scaling ⇒ Google::Apis::AppengineV1::BasicScaling
A service with basic scaling will create an instance when the application receives a request.
-
#beta_settings ⇒ Hash<String,String>
Metadata settings that are supplied to this version to enable beta runtime features.
-
#build_env_variables ⇒ Hash<String,String>
Environment variables available to the build environment.Only returned in GET requests if view=FULL is set.
-
#create_time ⇒ String
Time that this version was created.@OutputOnly Corresponds to the JSON property
createTime. -
#created_by ⇒ String
Output only.
-
#default_expiration ⇒ String
Duration that static files should be cached by web proxies and browsers.
-
#deployment ⇒ Google::Apis::AppengineV1::Deployment
Code and application artifacts used to deploy a version to App Engine.
-
#disk_usage_bytes ⇒ Fixnum
Output only.
-
#endpoints_api_service ⇒ Google::Apis::AppengineV1::EndpointsApiService
Google Cloud Endpoints (https://cloud.google.com/endpoints) configuration.
-
#entrypoint ⇒ Google::Apis::AppengineV1::Entrypoint
The entrypoint for the application.
-
#env ⇒ String
App Engine execution environment for this version.Defaults to standard.
-
#env_variables ⇒ Hash<String,String>
Environment variables available to the application.Only returned in GET requests if view=FULL is set.
-
#error_handlers ⇒ Array<Google::Apis::AppengineV1::ErrorHandler>
Custom static error pages.
-
#flexible_runtime_settings ⇒ Google::Apis::AppengineV1::FlexibleRuntimeSettings
Runtime settings for the App Engine flexible environment.
-
#generated_customer_metadata ⇒ Hash<String,Object>
Additional Google Generated Customer Metadata, this field won't be provided by default and can be requested by setting the IncludeExtraData field in GetVersionRequest Corresponds to the JSON property
generatedCustomerMetadata. -
#handlers ⇒ Array<Google::Apis::AppengineV1::UrlMap>
An ordered list of URL-matching patterns that should be applied to incoming requests.
-
#health_check ⇒ Google::Apis::AppengineV1::HealthCheck
Health checking configuration for VM instances.
-
#id ⇒ String
Relative name of the version within the service.
-
#inbound_services ⇒ Array<String>
Before an application can receive email or XMPP messages, the application must be configured to enable the service.
-
#instance_class ⇒ String
Instance class that is used to run this version.
-
#libraries ⇒ Array<Google::Apis::AppengineV1::Library>
Configuration for third-party Python runtime libraries that are required by the application.Only returned in GET requests if view=FULL is set.
-
#liveness_check ⇒ Google::Apis::AppengineV1::LivenessCheck
Health checking configuration for VM instances.
-
#manual_scaling ⇒ Google::Apis::AppengineV1::ManualScaling
A service with manual scaling runs continuously, allowing you to perform complex initialization and rely on the state of its memory over time.
-
#name ⇒ String
Output only.
-
#network ⇒ Google::Apis::AppengineV1::Network
Extra network settings.
-
#nobuild_files_regex ⇒ String
Files that match this pattern will not be built into this version.
-
#readiness_check ⇒ Google::Apis::AppengineV1::ReadinessCheck
Readiness checking configuration for VM instances.
-
#resources ⇒ Google::Apis::AppengineV1::Resources
Machine resources for a version.
-
#runtime ⇒ String
Desired runtime.
-
#runtime_api_version ⇒ String
The version of the API in the given runtime environment.
-
#runtime_channel ⇒ String
The channel of the runtime to use.
-
#runtime_main_executable_path ⇒ String
The path or name of the app's main executable.
-
#service_account ⇒ String
The identity that the deployed version will run as.
-
#serving_status ⇒ String
Current serving status of this version.
-
#threadsafe ⇒ Boolean
(also: #threadsafe?)
Whether multiple requests can be dispatched to this version at once.
-
#version_url ⇒ String
Output only.
-
#vm ⇒ Boolean
(also: #vm?)
Whether to deploy this version in a container on a virtual machine.
-
#vpc_access_connector ⇒ Google::Apis::AppengineV1::VpcAccessConnector
VPC access connector specification.
-
#zones ⇒ Array<String>
The Google Compute Engine zones that are supported by this version in the App Engine flexible environment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Version
constructor
A new instance of Version.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Version
Returns a new instance of Version.
3504 3505 3506 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3504 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_config ⇒ Google::Apis::AppengineV1::ApiConfigHandler
Google Cloud Endpoints (https://cloud.google.com/endpoints) configuration for
API handlers.
Corresponds to the JSON property apiConfig
3243 3244 3245 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3243 def api_config @api_config end |
#app_engine_apis ⇒ Boolean Also known as: app_engine_apis?
Allows App Engine second generation runtimes to access the legacy bundled
services.
Corresponds to the JSON property appEngineApis
3249 3250 3251 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3249 def app_engine_apis @app_engine_apis end |
#app_engine_bundled_services ⇒ Array<String>
List of specific App Engine Bundled Services that are enabled for this Version.
Corresponds to the JSON property appEngineBundledServices
3255 3256 3257 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3255 def app_engine_bundled_services @app_engine_bundled_services end |
#automatic_scaling ⇒ Google::Apis::AppengineV1::AutomaticScaling
Automatic scaling is based on request rate, response latencies, and other
application metrics.
Corresponds to the JSON property automaticScaling
3261 3262 3263 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3261 def automatic_scaling @automatic_scaling end |
#basic_scaling ⇒ Google::Apis::AppengineV1::BasicScaling
A service with basic scaling will create an instance when the application
receives a request. The instance will be turned down when the app becomes idle.
Basic scaling is ideal for work that is intermittent or driven by user
activity.
Corresponds to the JSON property basicScaling
3269 3270 3271 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3269 def basic_scaling @basic_scaling end |
#beta_settings ⇒ Hash<String,String>
Metadata settings that are supplied to this version to enable beta runtime
features.
Corresponds to the JSON property betaSettings
3275 3276 3277 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3275 def beta_settings @beta_settings end |
#build_env_variables ⇒ Hash<String,String>
Environment variables available to the build environment.Only returned in GET
requests if view=FULL is set.
Corresponds to the JSON property buildEnvVariables
3281 3282 3283 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3281 def build_env_variables @build_env_variables end |
#create_time ⇒ String
Time that this version was created.@OutputOnly
Corresponds to the JSON property createTime
3286 3287 3288 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3286 def create_time @create_time end |
#created_by ⇒ String
Output only. Email address of the user who created this version.@OutputOnly
Corresponds to the JSON property createdBy
3291 3292 3293 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3291 def created_by @created_by end |
#default_expiration ⇒ String
Duration that static files should be cached by web proxies and browsers. Only
applicable if the corresponding StaticFilesHandler (https://cloud.google.com/
appengine/docs/admin-api/reference/rest/v1/apps.services.versions#
StaticFilesHandler) does not specify its own expiration time.Only returned in
GET requests if view=FULL is set.
Corresponds to the JSON property defaultExpiration
3300 3301 3302 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3300 def default_expiration @default_expiration end |
#deployment ⇒ Google::Apis::AppengineV1::Deployment
Code and application artifacts used to deploy a version to App Engine.
Corresponds to the JSON property deployment
3305 3306 3307 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3305 def deployment @deployment end |
#disk_usage_bytes ⇒ Fixnum
Output only. Total size in bytes of all the files that are included in this
version and currently hosted on the App Engine disk.@OutputOnly
Corresponds to the JSON property diskUsageBytes
3311 3312 3313 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3311 def disk_usage_bytes @disk_usage_bytes end |
#endpoints_api_service ⇒ Google::Apis::AppengineV1::EndpointsApiService
Google Cloud Endpoints (https://cloud.google.com/endpoints) configuration. The
Endpoints API Service provides tooling for serving Open API and gRPC endpoints
via an NGINX proxy. Only valid for App Engine Flexible environment deployments.
The fields here refer to the name and configuration ID of a "service" resource
in the Service Management API (https://cloud.google.com/service-management/
overview).
Corresponds to the JSON property endpointsApiService
3321 3322 3323 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3321 def endpoints_api_service @endpoints_api_service end |
#entrypoint ⇒ Google::Apis::AppengineV1::Entrypoint
The entrypoint for the application.
Corresponds to the JSON property entrypoint
3326 3327 3328 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3326 def entrypoint @entrypoint end |
#env ⇒ String
App Engine execution environment for this version.Defaults to standard.
Corresponds to the JSON property env
3331 3332 3333 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3331 def env @env end |
#env_variables ⇒ Hash<String,String>
Environment variables available to the application.Only returned in GET
requests if view=FULL is set.
Corresponds to the JSON property envVariables
3337 3338 3339 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3337 def env_variables @env_variables end |
#error_handlers ⇒ Array<Google::Apis::AppengineV1::ErrorHandler>
Custom static error pages. Limited to 10KB per page.Only returned in GET
requests if view=FULL is set.
Corresponds to the JSON property errorHandlers
3343 3344 3345 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3343 def error_handlers @error_handlers end |
#flexible_runtime_settings ⇒ Google::Apis::AppengineV1::FlexibleRuntimeSettings
Runtime settings for the App Engine flexible environment.
Corresponds to the JSON property flexibleRuntimeSettings
3348 3349 3350 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3348 def flexible_runtime_settings @flexible_runtime_settings end |
#generated_customer_metadata ⇒ Hash<String,Object>
Additional Google Generated Customer Metadata, this field won't be provided by
default and can be requested by setting the IncludeExtraData field in
GetVersionRequest
Corresponds to the JSON property generatedCustomerMetadata
3355 3356 3357 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3355 def @generated_customer_metadata end |
#handlers ⇒ Array<Google::Apis::AppengineV1::UrlMap>
An ordered list of URL-matching patterns that should be applied to incoming
requests. The first matching URL handles the request and other request
handlers are not attempted.Only returned in GET requests if view=FULL is set.
Corresponds to the JSON property handlers
3362 3363 3364 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3362 def handlers @handlers end |
#health_check ⇒ Google::Apis::AppengineV1::HealthCheck
Health checking configuration for VM instances. Unhealthy instances are killed
and replaced with new instances. Only applicable for instances in App Engine
flexible environment.
Corresponds to the JSON property healthCheck
3369 3370 3371 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3369 def health_check @health_check end |
#id ⇒ String
Relative name of the version within the service. Example: v1. Version names
can contain only lowercase letters, numbers, or hyphens. Reserved names: "
default", "latest", and any name with the prefix "ah-".
Corresponds to the JSON property id
3376 3377 3378 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3376 def id @id end |
#inbound_services ⇒ Array<String>
Before an application can receive email or XMPP messages, the application must
be configured to enable the service.
Corresponds to the JSON property inboundServices
3382 3383 3384 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3382 def inbound_services @inbound_services end |
#instance_class ⇒ String
Instance class that is used to run this version. Valid values are:
AutomaticScaling: F1, F2, F4, F4_1G ManualScaling or BasicScaling: B1, B2, B4,
B8, B4_1GDefaults to F1 for AutomaticScaling and B1 for ManualScaling or
BasicScaling.
Corresponds to the JSON property instanceClass
3390 3391 3392 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3390 def instance_class @instance_class end |
#libraries ⇒ Array<Google::Apis::AppengineV1::Library>
Configuration for third-party Python runtime libraries that are required by
the application.Only returned in GET requests if view=FULL is set.
Corresponds to the JSON property libraries
3396 3397 3398 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3396 def libraries @libraries end |
#liveness_check ⇒ Google::Apis::AppengineV1::LivenessCheck
Health checking configuration for VM instances. Unhealthy instances are killed
and replaced with new instances.
Corresponds to the JSON property livenessCheck
3402 3403 3404 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3402 def liveness_check @liveness_check end |
#manual_scaling ⇒ Google::Apis::AppengineV1::ManualScaling
A service with manual scaling runs continuously, allowing you to perform
complex initialization and rely on the state of its memory over time.
Corresponds to the JSON property manualScaling
3408 3409 3410 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3408 def manual_scaling @manual_scaling end |
#name ⇒ String
Output only. Full path to the Version resource in the API. Example: apps/myapp/
services/default/versions/v1.@OutputOnly
Corresponds to the JSON property name
3414 3415 3416 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3414 def name @name end |
#network ⇒ Google::Apis::AppengineV1::Network
Extra network settings. Only applicable in the App Engine flexible environment.
Corresponds to the JSON property network
3419 3420 3421 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3419 def network @network end |
#nobuild_files_regex ⇒ String
Files that match this pattern will not be built into this version. Only
applicable for Go runtimes.Only returned in GET requests if view=FULL is set.
Corresponds to the JSON property nobuildFilesRegex
3425 3426 3427 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3425 def nobuild_files_regex @nobuild_files_regex end |
#readiness_check ⇒ Google::Apis::AppengineV1::ReadinessCheck
Readiness checking configuration for VM instances. Unhealthy instances are
removed from traffic rotation.
Corresponds to the JSON property readinessCheck
3431 3432 3433 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3431 def readiness_check @readiness_check end |
#resources ⇒ Google::Apis::AppengineV1::Resources
Machine resources for a version.
Corresponds to the JSON property resources
3436 3437 3438 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3436 def resources @resources end |
#runtime ⇒ String
Desired runtime. Example: python27.
Corresponds to the JSON property runtime
3441 3442 3443 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3441 def runtime @runtime end |
#runtime_api_version ⇒ String
The version of the API in the given runtime environment. Please see the app.
yaml reference for valid values at https://cloud.google.com/appengine/docs/
standard//config/appref
Corresponds to the JSON property runtimeApiVersion
3448 3449 3450 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3448 def runtime_api_version @runtime_api_version end |
#runtime_channel ⇒ String
The channel of the runtime to use. Only available for some runtimes. Defaults
to the default channel.
Corresponds to the JSON property runtimeChannel
3454 3455 3456 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3454 def runtime_channel @runtime_channel end |
#runtime_main_executable_path ⇒ String
The path or name of the app's main executable.
Corresponds to the JSON property runtimeMainExecutablePath
3459 3460 3461 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3459 def runtime_main_executable_path @runtime_main_executable_path end |
#service_account ⇒ String
The identity that the deployed version will run as. Admin API will use the App
Engine Appspot service account as default if this field is neither provided in
app.yaml file nor through CLI flag.
Corresponds to the JSON property serviceAccount
3466 3467 3468 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3466 def service_account @service_account end |
#serving_status ⇒ String
Current serving status of this version. Only the versions with a SERVING
status create instances and can be billed.SERVING_STATUS_UNSPECIFIED is an
invalid value. Defaults to SERVING.
Corresponds to the JSON property servingStatus
3473 3474 3475 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3473 def serving_status @serving_status end |
#threadsafe ⇒ Boolean Also known as: threadsafe?
Whether multiple requests can be dispatched to this version at once.
Corresponds to the JSON property threadsafe
3478 3479 3480 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3478 def threadsafe @threadsafe end |
#version_url ⇒ String
Output only. Serving URL for this version. Example: "https://myversion-dot-
myservice-dot-myapp.appspot.com"@OutputOnly
Corresponds to the JSON property versionUrl
3485 3486 3487 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3485 def version_url @version_url end |
#vm ⇒ Boolean Also known as: vm?
Whether to deploy this version in a container on a virtual machine.
Corresponds to the JSON property vm
3490 3491 3492 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3490 def vm @vm end |
#vpc_access_connector ⇒ Google::Apis::AppengineV1::VpcAccessConnector
VPC access connector specification.
Corresponds to the JSON property vpcAccessConnector
3496 3497 3498 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3496 def vpc_access_connector @vpc_access_connector end |
#zones ⇒ Array<String>
The Google Compute Engine zones that are supported by this version in the App
Engine flexible environment. Deprecated.
Corresponds to the JSON property zones
3502 3503 3504 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3502 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 3523 3524 3525 3526 3527 3528 3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 |
# File 'lib/google/apis/appengine_v1/classes.rb', line 3509 def update!(**args) @api_config = args[:api_config] if args.key?(:api_config) @app_engine_apis = args[:app_engine_apis] if args.key?(:app_engine_apis) @app_engine_bundled_services = args[:app_engine_bundled_services] if args.key?(:app_engine_bundled_services) @automatic_scaling = args[:automatic_scaling] if args.key?(:automatic_scaling) @basic_scaling = args[:basic_scaling] if args.key?(:basic_scaling) @beta_settings = args[:beta_settings] if args.key?(:beta_settings) @build_env_variables = args[:build_env_variables] if args.key?(:build_env_variables) @create_time = args[:create_time] if args.key?(:create_time) @created_by = args[:created_by] if args.key?(:created_by) @default_expiration = args[:default_expiration] if args.key?(:default_expiration) @deployment = args[:deployment] if args.key?(:deployment) @disk_usage_bytes = args[:disk_usage_bytes] if args.key?(:disk_usage_bytes) @endpoints_api_service = args[:endpoints_api_service] if args.key?(:endpoints_api_service) @entrypoint = args[:entrypoint] if args.key?(:entrypoint) @env = args[:env] if args.key?(:env) @env_variables = args[:env_variables] if args.key?(:env_variables) @error_handlers = args[:error_handlers] if args.key?(:error_handlers) @flexible_runtime_settings = args[:flexible_runtime_settings] if args.key?(:flexible_runtime_settings) @generated_customer_metadata = args[:generated_customer_metadata] if args.key?(:generated_customer_metadata) @handlers = args[:handlers] if args.key?(:handlers) @health_check = args[:health_check] if args.key?(:health_check) @id = args[:id] if args.key?(:id) @inbound_services = args[:inbound_services] if args.key?(:inbound_services) @instance_class = args[:instance_class] if args.key?(:instance_class) @libraries = args[:libraries] if args.key?(:libraries) @liveness_check = args[:liveness_check] if args.key?(:liveness_check) @manual_scaling = args[:manual_scaling] if args.key?(:manual_scaling) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @nobuild_files_regex = args[:nobuild_files_regex] if args.key?(:nobuild_files_regex) @readiness_check = args[:readiness_check] if args.key?(:readiness_check) @resources = args[:resources] if args.key?(:resources) @runtime = args[:runtime] if args.key?(:runtime) @runtime_api_version = args[:runtime_api_version] if args.key?(:runtime_api_version) @runtime_channel = args[:runtime_channel] if args.key?(:runtime_channel) @runtime_main_executable_path = args[:runtime_main_executable_path] if args.key?(:runtime_main_executable_path) @service_account = args[:service_account] if args.key?(:service_account) @serving_status = args[:serving_status] if args.key?(:serving_status) @threadsafe = args[:threadsafe] if args.key?(:threadsafe) @version_url = args[:version_url] if args.key?(:version_url) @vm = args[:vm] if args.key?(:vm) @vpc_access_connector = args[:vpc_access_connector] if args.key?(:vpc_access_connector) @zones = args[:zones] if args.key?(:zones) end |