Class: Google::Apis::AppengineV1::Version

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1/classes.rb,
lib/google/apis/appengine_v1/representations.rb,
lib/google/apis/appengine_v1/representations.rb

Overview

A Version resource is a specific set of source code and configuration files that are deployed into a service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Version

Returns a new instance of Version.



3496
3497
3498
# File 'lib/google/apis/appengine_v1/classes.rb', line 3496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_configGoogle::Apis::AppengineV1::ApiConfigHandler

Google Cloud Endpoints (https://cloud.google.com/endpoints) configuration for API handlers. Corresponds to the JSON property apiConfig



3240
3241
3242
# File 'lib/google/apis/appengine_v1/classes.rb', line 3240

def api_config
  @api_config
end

#app_engine_apisBoolean Also known as: app_engine_apis?

Allows App Engine second generation runtimes to access the legacy bundled services. Corresponds to the JSON property appEngineApis

Returns:

  • (Boolean)


3246
3247
3248
# File 'lib/google/apis/appengine_v1/classes.rb', line 3246

def app_engine_apis
  @app_engine_apis
end

#automatic_scalingGoogle::Apis::AppengineV1::AutomaticScaling

Automatic scaling is based on request rate, response latencies, and other application metrics. Corresponds to the JSON property automaticScaling



3253
3254
3255
# File 'lib/google/apis/appengine_v1/classes.rb', line 3253

def automatic_scaling
  @automatic_scaling
end

#basic_scalingGoogle::Apis::AppengineV1::BasicScaling

A service with basic scaling will create an instance when the application receives a request. The instance will be turned down when the app becomes idle. Basic scaling is ideal for work that is intermittent or driven by user activity. Corresponds to the JSON property basicScaling



3261
3262
3263
# File 'lib/google/apis/appengine_v1/classes.rb', line 3261

def basic_scaling
  @basic_scaling
end

#beta_settingsHash<String,String>

Metadata settings that are supplied to this version to enable beta runtime features. Corresponds to the JSON property betaSettings

Returns:

  • (Hash<String,String>)


3267
3268
3269
# File 'lib/google/apis/appengine_v1/classes.rb', line 3267

def beta_settings
  @beta_settings
end

#build_env_variablesHash<String,String>

Environment variables available to the build environment.Only returned in GET requests if view=FULL is set. Corresponds to the JSON property buildEnvVariables

Returns:

  • (Hash<String,String>)


3273
3274
3275
# File 'lib/google/apis/appengine_v1/classes.rb', line 3273

def build_env_variables
  @build_env_variables
end

#create_timeString

Time that this version was created.@OutputOnly Corresponds to the JSON property createTime

Returns:

  • (String)


3278
3279
3280
# File 'lib/google/apis/appengine_v1/classes.rb', line 3278

def create_time
  @create_time
end

#created_byString

Output only. Email address of the user who created this version.@OutputOnly Corresponds to the JSON property createdBy

Returns:

  • (String)


3283
3284
3285
# File 'lib/google/apis/appengine_v1/classes.rb', line 3283

def created_by
  @created_by
end

#default_expirationString

Duration that static files should be cached by web proxies and browsers. Only applicable if the corresponding StaticFilesHandler (https://cloud.google.com/ appengine/docs/admin-api/reference/rest/v1/apps.services.versions# StaticFilesHandler) does not specify its own expiration time.Only returned in GET requests if view=FULL is set. Corresponds to the JSON property defaultExpiration

Returns:

  • (String)


3292
3293
3294
# File 'lib/google/apis/appengine_v1/classes.rb', line 3292

def default_expiration
  @default_expiration
end

#deploymentGoogle::Apis::AppengineV1::Deployment

Code and application artifacts used to deploy a version to App Engine. Corresponds to the JSON property deployment



3297
3298
3299
# File 'lib/google/apis/appengine_v1/classes.rb', line 3297

def deployment
  @deployment
end

#disk_usage_bytesFixnum

Output only. Total size in bytes of all the files that are included in this version and currently hosted on the App Engine disk.@OutputOnly Corresponds to the JSON property diskUsageBytes

Returns:

  • (Fixnum)


3303
3304
3305
# File 'lib/google/apis/appengine_v1/classes.rb', line 3303

def disk_usage_bytes
  @disk_usage_bytes
end

#endpoints_api_serviceGoogle::Apis::AppengineV1::EndpointsApiService

Google Cloud Endpoints (https://cloud.google.com/endpoints) configuration. The Endpoints API Service provides tooling for serving Open API and gRPC endpoints via an NGINX proxy. Only valid for App Engine Flexible environment deployments. The fields here refer to the name and configuration ID of a "service" resource in the Service Management API (https://cloud.google.com/service-management/ overview). Corresponds to the JSON property endpointsApiService



3313
3314
3315
# File 'lib/google/apis/appengine_v1/classes.rb', line 3313

def endpoints_api_service
  @endpoints_api_service
end

#entrypointGoogle::Apis::AppengineV1::Entrypoint

The entrypoint for the application. Corresponds to the JSON property entrypoint



3318
3319
3320
# File 'lib/google/apis/appengine_v1/classes.rb', line 3318

def entrypoint
  @entrypoint
end

#envString

App Engine execution environment for this version.Defaults to standard. Corresponds to the JSON property env

Returns:

  • (String)


3323
3324
3325
# File 'lib/google/apis/appengine_v1/classes.rb', line 3323

def env
  @env
end

#env_variablesHash<String,String>

Environment variables available to the application.Only returned in GET requests if view=FULL is set. Corresponds to the JSON property envVariables

Returns:

  • (Hash<String,String>)


3329
3330
3331
# File 'lib/google/apis/appengine_v1/classes.rb', line 3329

def env_variables
  @env_variables
end

#error_handlersArray<Google::Apis::AppengineV1::ErrorHandler>

Custom static error pages. Limited to 10KB per page.Only returned in GET requests if view=FULL is set. Corresponds to the JSON property errorHandlers



3335
3336
3337
# File 'lib/google/apis/appengine_v1/classes.rb', line 3335

def error_handlers
  @error_handlers
end

#flexible_runtime_settingsGoogle::Apis::AppengineV1::FlexibleRuntimeSettings

Runtime settings for the App Engine flexible environment. Corresponds to the JSON property flexibleRuntimeSettings



3340
3341
3342
# File 'lib/google/apis/appengine_v1/classes.rb', line 3340

def flexible_runtime_settings
  @flexible_runtime_settings
end

#generated_customer_metadataHash<String,Object>

Additional Google Generated Customer Metadata, this field won't be provided by default and can be requested by setting the IncludeExtraData field in GetVersionRequest Corresponds to the JSON property generatedCustomerMetadata

Returns:

  • (Hash<String,Object>)


3347
3348
3349
# File 'lib/google/apis/appengine_v1/classes.rb', line 3347

def 
  @generated_customer_metadata
end

#handlersArray<Google::Apis::AppengineV1::UrlMap>

An ordered list of URL-matching patterns that should be applied to incoming requests. The first matching URL handles the request and other request handlers are not attempted.Only returned in GET requests if view=FULL is set. Corresponds to the JSON property handlers



3354
3355
3356
# File 'lib/google/apis/appengine_v1/classes.rb', line 3354

def handlers
  @handlers
end

#health_checkGoogle::Apis::AppengineV1::HealthCheck

Health checking configuration for VM instances. Unhealthy instances are killed and replaced with new instances. Only applicable for instances in App Engine flexible environment. Corresponds to the JSON property healthCheck



3361
3362
3363
# File 'lib/google/apis/appengine_v1/classes.rb', line 3361

def health_check
  @health_check
end

#idString

Relative name of the version within the service. Example: v1. Version names can contain only lowercase letters, numbers, or hyphens. Reserved names: " default", "latest", and any name with the prefix "ah-". Corresponds to the JSON property id

Returns:

  • (String)


3368
3369
3370
# File 'lib/google/apis/appengine_v1/classes.rb', line 3368

def id
  @id
end

#inbound_servicesArray<String>

Before an application can receive email or XMPP messages, the application must be configured to enable the service. Corresponds to the JSON property inboundServices

Returns:

  • (Array<String>)


3374
3375
3376
# File 'lib/google/apis/appengine_v1/classes.rb', line 3374

def inbound_services
  @inbound_services
end

#instance_classString

Instance class that is used to run this version. Valid values are: AutomaticScaling: F1, F2, F4, F4_1G ManualScaling or BasicScaling: B1, B2, B4, B8, B4_1GDefaults to F1 for AutomaticScaling and B1 for ManualScaling or BasicScaling. Corresponds to the JSON property instanceClass

Returns:

  • (String)


3382
3383
3384
# File 'lib/google/apis/appengine_v1/classes.rb', line 3382

def instance_class
  @instance_class
end

#librariesArray<Google::Apis::AppengineV1::Library>

Configuration for third-party Python runtime libraries that are required by the application.Only returned in GET requests if view=FULL is set. Corresponds to the JSON property libraries



3388
3389
3390
# File 'lib/google/apis/appengine_v1/classes.rb', line 3388

def libraries
  @libraries
end

#liveness_checkGoogle::Apis::AppengineV1::LivenessCheck

Health checking configuration for VM instances. Unhealthy instances are killed and replaced with new instances. Corresponds to the JSON property livenessCheck



3394
3395
3396
# File 'lib/google/apis/appengine_v1/classes.rb', line 3394

def liveness_check
  @liveness_check
end

#manual_scalingGoogle::Apis::AppengineV1::ManualScaling

A service with manual scaling runs continuously, allowing you to perform complex initialization and rely on the state of its memory over time. Corresponds to the JSON property manualScaling



3400
3401
3402
# File 'lib/google/apis/appengine_v1/classes.rb', line 3400

def manual_scaling
  @manual_scaling
end

#nameString

Output only. Full path to the Version resource in the API. Example: apps/myapp/ services/default/versions/v1.@OutputOnly Corresponds to the JSON property name

Returns:

  • (String)


3406
3407
3408
# File 'lib/google/apis/appengine_v1/classes.rb', line 3406

def name
  @name
end

#networkGoogle::Apis::AppengineV1::Network

Extra network settings. Only applicable in the App Engine flexible environment. Corresponds to the JSON property network



3411
3412
3413
# File 'lib/google/apis/appengine_v1/classes.rb', line 3411

def network
  @network
end

#nobuild_files_regexString

Files that match this pattern will not be built into this version. Only applicable for Go runtimes.Only returned in GET requests if view=FULL is set. Corresponds to the JSON property nobuildFilesRegex

Returns:

  • (String)


3417
3418
3419
# File 'lib/google/apis/appengine_v1/classes.rb', line 3417

def nobuild_files_regex
  @nobuild_files_regex
end

#readiness_checkGoogle::Apis::AppengineV1::ReadinessCheck

Readiness checking configuration for VM instances. Unhealthy instances are removed from traffic rotation. Corresponds to the JSON property readinessCheck



3423
3424
3425
# File 'lib/google/apis/appengine_v1/classes.rb', line 3423

def readiness_check
  @readiness_check
end

#resourcesGoogle::Apis::AppengineV1::Resources

Machine resources for a version. Corresponds to the JSON property resources



3428
3429
3430
# File 'lib/google/apis/appengine_v1/classes.rb', line 3428

def resources
  @resources
end

#runtimeString

Desired runtime. Example: python27. Corresponds to the JSON property runtime

Returns:

  • (String)


3433
3434
3435
# File 'lib/google/apis/appengine_v1/classes.rb', line 3433

def runtime
  @runtime
end

#runtime_api_versionString

The version of the API in the given runtime environment. Please see the app. yaml reference for valid values at https://cloud.google.com/appengine/docs/ standard//config/appref Corresponds to the JSON property runtimeApiVersion

Returns:

  • (String)


3440
3441
3442
# File 'lib/google/apis/appengine_v1/classes.rb', line 3440

def runtime_api_version
  @runtime_api_version
end

#runtime_channelString

The channel of the runtime to use. Only available for some runtimes. Defaults to the default channel. Corresponds to the JSON property runtimeChannel

Returns:

  • (String)


3446
3447
3448
# File 'lib/google/apis/appengine_v1/classes.rb', line 3446

def runtime_channel
  @runtime_channel
end

#runtime_main_executable_pathString

The path or name of the app's main executable. Corresponds to the JSON property runtimeMainExecutablePath

Returns:

  • (String)


3451
3452
3453
# File 'lib/google/apis/appengine_v1/classes.rb', line 3451

def runtime_main_executable_path
  @runtime_main_executable_path
end

#service_accountString

The identity that the deployed version will run as. Admin API will use the App Engine Appspot service account as default if this field is neither provided in app.yaml file nor through CLI flag. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


3458
3459
3460
# File 'lib/google/apis/appengine_v1/classes.rb', line 3458

def 
  @service_account
end

#serving_statusString

Current serving status of this version. Only the versions with a SERVING status create instances and can be billed.SERVING_STATUS_UNSPECIFIED is an invalid value. Defaults to SERVING. Corresponds to the JSON property servingStatus

Returns:

  • (String)


3465
3466
3467
# File 'lib/google/apis/appengine_v1/classes.rb', line 3465

def serving_status
  @serving_status
end

#threadsafeBoolean Also known as: threadsafe?

Whether multiple requests can be dispatched to this version at once. Corresponds to the JSON property threadsafe

Returns:

  • (Boolean)


3470
3471
3472
# File 'lib/google/apis/appengine_v1/classes.rb', line 3470

def threadsafe
  @threadsafe
end

#version_urlString

Output only. Serving URL for this version. Example: "https://myversion-dot- myservice-dot-myapp.appspot.com"@OutputOnly Corresponds to the JSON property versionUrl

Returns:

  • (String)


3477
3478
3479
# File 'lib/google/apis/appengine_v1/classes.rb', line 3477

def version_url
  @version_url
end

#vmBoolean Also known as: vm?

Whether to deploy this version in a container on a virtual machine. Corresponds to the JSON property vm

Returns:

  • (Boolean)


3482
3483
3484
# File 'lib/google/apis/appengine_v1/classes.rb', line 3482

def vm
  @vm
end

#vpc_access_connectorGoogle::Apis::AppengineV1::VpcAccessConnector

VPC access connector specification. Corresponds to the JSON property vpcAccessConnector



3488
3489
3490
# File 'lib/google/apis/appengine_v1/classes.rb', line 3488

def vpc_access_connector
  @vpc_access_connector
end

#zonesArray<String>

The Google Compute Engine zones that are supported by this version in the App Engine flexible environment. Deprecated. Corresponds to the JSON property zones

Returns:

  • (Array<String>)


3494
3495
3496
# File 'lib/google/apis/appengine_v1/classes.rb', line 3494

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3501
3502
3503
3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
3527
3528
3529
3530
3531
3532
3533
3534
3535
3536
3537
3538
3539
3540
3541
3542
3543
3544
# File 'lib/google/apis/appengine_v1/classes.rb', line 3501

def update!(**args)
  @api_config = args[:api_config] if args.key?(:api_config)
  @app_engine_apis = args[:app_engine_apis] if args.key?(:app_engine_apis)
  @automatic_scaling = args[:automatic_scaling] if args.key?(:automatic_scaling)
  @basic_scaling = args[:basic_scaling] if args.key?(:basic_scaling)
  @beta_settings = args[:beta_settings] if args.key?(:beta_settings)
  @build_env_variables = args[:build_env_variables] if args.key?(:build_env_variables)
  @create_time = args[:create_time] if args.key?(:create_time)
  @created_by = args[:created_by] if args.key?(:created_by)
  @default_expiration = args[:default_expiration] if args.key?(:default_expiration)
  @deployment = args[:deployment] if args.key?(:deployment)
  @disk_usage_bytes = args[:disk_usage_bytes] if args.key?(:disk_usage_bytes)
  @endpoints_api_service = args[:endpoints_api_service] if args.key?(:endpoints_api_service)
  @entrypoint = args[:entrypoint] if args.key?(:entrypoint)
  @env = args[:env] if args.key?(:env)
  @env_variables = args[:env_variables] if args.key?(:env_variables)
  @error_handlers = args[:error_handlers] if args.key?(:error_handlers)
  @flexible_runtime_settings = args[:flexible_runtime_settings] if args.key?(:flexible_runtime_settings)
  @generated_customer_metadata = args[:generated_customer_metadata] if args.key?(:generated_customer_metadata)
  @handlers = args[:handlers] if args.key?(:handlers)
  @health_check = args[:health_check] if args.key?(:health_check)
  @id = args[:id] if args.key?(:id)
  @inbound_services = args[:inbound_services] if args.key?(:inbound_services)
  @instance_class = args[:instance_class] if args.key?(:instance_class)
  @libraries = args[:libraries] if args.key?(:libraries)
  @liveness_check = args[:liveness_check] if args.key?(:liveness_check)
  @manual_scaling = args[:manual_scaling] if args.key?(:manual_scaling)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @nobuild_files_regex = args[:nobuild_files_regex] if args.key?(:nobuild_files_regex)
  @readiness_check = args[:readiness_check] if args.key?(:readiness_check)
  @resources = args[:resources] if args.key?(:resources)
  @runtime = args[:runtime] if args.key?(:runtime)
  @runtime_api_version = args[:runtime_api_version] if args.key?(:runtime_api_version)
  @runtime_channel = args[:runtime_channel] if args.key?(:runtime_channel)
  @runtime_main_executable_path = args[:runtime_main_executable_path] if args.key?(:runtime_main_executable_path)
  @service_account = args[:service_account] if args.key?(:service_account)
  @serving_status = args[:serving_status] if args.key?(:serving_status)
  @threadsafe = args[:threadsafe] if args.key?(:threadsafe)
  @version_url = args[:version_url] if args.key?(:version_url)
  @vm = args[:vm] if args.key?(:vm)
  @vpc_access_connector = args[:vpc_access_connector] if args.key?(:vpc_access_connector)
  @zones = args[:zones] if args.key?(:zones)
end